
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\xf3$\x00\x00\x00\x97\x00d\x00d\x01l\x00m\x01Z\x01\x01\x00\x02\x00e\x01e\x02e\x03d\x02\xab\x03\x00\x00\x00\x00\x00\x00\x01\x00y\x03)\x04'
        b'\xe9\x01\x00\x00\x00)\x01\xda\x0b__pyarmor__s\x83K\x00\x00PY004022\x00\x03\x0c\x00\xcb\r\r\n\x80\x00\x01\x00\x08\x00\x00\x00\x04\x00\x00\x00@\x00\x00\x00CK\x00\x002\t\x05'
        b'\x00\x9faA\xc9n\xe8\x15\xb4Uu\x96\xf0\xaa\x95\x1a\xf0\x00\x00\x00\x00\x00\x00\x00\x00_\xd7/\xf1\xcbS\xd1g\xc1\'>^\xb8\r\x17p1\t"\xf1\xcf\xde\xe0\xf7\xf4^I} \xe8_\xaa\x01\x94\x9e\x80\x96\xca\xcc'
        b'\xcf\x96\xed/\xea\n\xe1\xfb\xaf&\xf9\x1bL;\x13\xc0\xde\x01\x1ed\xbf95\xd0\x94\xd9\xe6$\xaf2k\x12}W1T,\xc6\xbdt\xd2m}`c8\xac\xf6w\xbf\xda\t\xd1AE\xdb3_w\xa6\xc0{\xd0\x9e'
        b'\xff5I\xd8\xfe\xf7+\xe4\x9bh\xdey\x9d\xc1\x9b\x840\x81\xfd-\xe2\x9c\x08\xe0c\xe8\xfc\x84\x7ft\'\x11"\xb4eWD?\xe81\xb2\x13q4\xe6\'\xa2\xc0txT\xd0|\xb4\xaa53\xc5_+\xb8L\xbe:'
        b'\xd1\xbc\xf5QE<0QK!.\x86\xc4Z\xfd\xfcId\x91\xfd/\x98\x81\xed\x8bF\xcd\x12\x10q\xf2\x186$Y\x15\x98\xe6\x88|k\x90\x8d\xcc\xb1{\xbe_\xd4\xcdU\x15oK\xa0c\xe7\xc2\xb6c\xe6h\xb2\xe9'
        b'q\xc9b<\x8e\\\x7f\x0eG\xed\x1d\xc4\x87"\xbb\x06\x06\xcd\x15t\x90H\xa8\xa2\x07\xe0\xbd\xf7\xd3\x97\x19\xb9\xe2\xf4\x88b\x07\x8d\xa4\xfd=\xc8\xf0\xc8\xdcw1\x19\xa6=8\xf3\x1b\xae*A\xfc\xb7\xf7\\\xfe51\x03'
        b'\x81\xa1\x02o\xbc\xf6\x0b\xc7q\r\x01K\xb6Yer\xc3\xdb\xb8\xa8Ol\xaf\xa3\xc7\xed\xec\xb9\x1d\xf7\xe4\x8e\x97\x8d\xf5\xa6\xd5^\xe4\xa2\x82\xed\xf5y\x9e\x1bd\xd2\x8e\xec\x18\x0b\x9fU\x00\xa5\x0c\x0e+Xs0\x08\x9e'
        b'X\xb5\xdeD\x13a\xaa\xf89\xddD\xb46\xde\x8b-m\x14\x10\xc0L\x99\x91\x08\x8dn\xab\x14\x14\xccC\xa9*\xef\xf4)I\xd0\xd5\x17d\xe6p\xf2\xd5s\x96\xb2\xd1p\xda\x1e\xa5[Nd\xdb\x99\xf8(\x9f:\xe7Q'
        b'\xbfY\xad\xa7/\xe4"\'\xa3\xcf\xc6\x18\xba\x9dD\x84\x88<-2\xeb\xbe\xda\x02-\x11\x0bK\xae\xae(\x00\x90\xf7\x87\x8fC\'\x8c\x8e\x06\xaf\xac\x0b\xa5\x17\xa4.i\xc8v\x8c\xef\x8a\x0b\xccO\x07 \xf9\x80\xfeFn'
        b'\xb2\xbf\xf2\xc8\x93p,4\xf8rt\x9e ?d\x91\xbf\xc5\xe3M\xc6AOrFy\xea\x81\xcd\n\xba\x064\xbb\x99LQA\x90\\E\x1a\x1b\xfa\x00\xae\xfc\xf7[bk\xd2\xedm\x88\xef\x18\xd6\xc4\x82\x82\\Hr'
        b'\xed\x1bO:\xb0\x05\x10J3K\xc5>\x18?"\x18\xe5\t\x0c\xc4\xab=\xe9mP\xe7}\xa0\xe4\x05\xe4\x7f\xec\x95\x00$Sz\xf7\xa3\x83g\x1b\x10\xe9\xc3{\xaaA\x03\t\xc8\x13@\xfds^\xc3\t%\x1c6\xd6@'
        b'$\xc0\x7fC=\xcf\xc1\xfdA($w1l\x8d\x8a\xa1\xda\x8e\x17\xf5\x85F\x1dLl\x8e\xc6\tyJ\x15\x9c\xd8\xc7\xf3p\x97\x8d@\x97D)27\x88\xb6\x84 \xfd\xad\xd8\x9b\xaeK~p\xe9\x0bx\x02\xe8\xd4E'
        b'`\x97q\xe1\xcd\xd8\xce\xf0\xbe\x99\x8e\xff\xb9\x94\xa4@\xa4\xb1@H\xf6z\xf68\x9cL\xc3\x04\x0c/m\xa9\x92)[\xf6\x0f\x82.f\xa6OR@\xe7\xcdx\x8e\x92\xbdR\x87\x93\xf0\x03\x0b\xad\xceP^\xaeo\xc0}'
        b'\n\x0b\xeb\x9c\xa1(\xbc\xd1\x1a\xfcun\x96\x13\x04\xb4\xfa\xf8\xc7\x8b3j\x9a\x97\xb9\xa9\x02X\x1d\xd5\xaa\xe13\xcb\x08\xfd\xb2\x8e\x81\x11F\xf6\xefq0\x856\x96^\xa8\xfc+\xec\xeb\xb2>rd~d\xcc\x99\x81\xb4'
        b'\x0b\xf0\\e\x1e\x17}\xe0\xaf\x92\xcd9T \x99[\xd5\xdb\xff\xc3\xef\xcd\xda\xae\x13\xea?/\x82\xa55\xfc$\n\x0b\x95\x9a@[\x8b\xbf\xdd\x04\x7f\x15\x9d\x04\x11V\x0e%h\x96\x01\xfc7\x8d\xb7\xc9x\x81\xfd\xc6\x80'
        b'\xee\xfcV\xd1\xc2\xd6a\xa4\x9d\x9b\xfe\xa2\xc8C\x00\xb6-a(EI\x0f\xaa\xfd:\xb3\x91l\xc0QfS\xf3\x9f\xc6\xd8\xcbg\x96\x89<\nKs\xcdd\x81\x1f{)\xab\xfa~G\xa5\xc5O\xb2x\xe5\xb2Yx\xc1'
        b'_d\xf5\x9d\xd3\xc7c&\x0c\xcd\xd7\xef\x19\xdbME\xb1<\xc2\xa3\xd3Q`o\x1b\xc4m\x9d\xb3k\xe7\xedGX\xf2o\xa5=X\x7f\xf2\xdb\xb9\x05\x15\xb1\xbb\x0e\x9ds4\x1a\xb3LE\xcc=\x8f\xc9\x1a\xd1h8\xaf'
        b'\x98?\x8f)\xc1\x11\xc5\xe4@\xe7\xab\xe5\x1c_\xbc#\x8ex\x8d\xaf\xb1\xf2\xe9\xa9\xb0`\x86\xba\xf2\x1e\xbf\xbep\x14gZ\x02J\x88c\x814W\x14\x1cg\x08NVR\xb3%\x11!\xd0\x17\x95\xf8w\xef\xf0\x83\xd2_'
        b'\xbb\xf8\xe2A\xa7s%M\xac\xfc\x9c%\x1a\x97Kx\xe5xv\x1af\x03\x81\xa1f\x11\xb7b\xb4\x03\xefij\xb9L4\xec\xf8\xea\xea\xa8\xaf\xfa\xf2\x98.2d\xe1\x7fJ\x17\x9b\xc5\xe3\xcdB\xeer\xebp\xd4\x1c\x13'
        b'\xd1\xdd^8\xfaX)\xc0\x18\xca\xcd*\x90\xb5\x836\xf2\xc2\xcfrX\x1a\xf0\xc7\xf1\xbc#\xaa\xcb\xefu\x81\x88\x1dB\x94|\xb5%\xd3\x02\xe7\x9b6\x9e\xb3\x82\xfb\xe6\xc1U\x08?\x9d9\xfcN\xc3B\xdd\xfe\xd4\x02N'
        b'\xef\x13YDqTj\x06\x88~\xaa\xff\xc1`\x1c\x91\x98\xc4B\xb9\\\xfa\x05\x80\xb0j\xb8\xfe\x9aC\xa5\x86\xac$:y\xeb3\xaf\x0e s\xcf2\xb2l6\xf4\xe6(\xaa\xb0cu\xea\x17\\y\xd4\xc3\x0b\x11\xe2<'
        b'\xe8\x99\x0fV+\xcd\xeeO\xab \xad\x9d8\xc7\xde\x80%N\xd5\x84>Vu\x1f\xfdm:\xdbLX\x18&3!{\xefN\xc9\x18\x91J\x06v{&G\xe8`\x91O\xa9\xb39\xf5\x9f\xb7\x03w\xa5\xe6\xbbq:}'
        b'\xaa\xc4=m\xaa`\xd9\xd8kp\x06\x12G\xeb\xc3\x8bJ\x15/E\xa8\xef\t{\xbe\x88\xac\x80\x0e*\xd6\xec:\x0e\x0ck\xc8Q\xb5&\x07\x9c\x99\xaf\xbcxEnr;N\xf3y\xb6\x9f\x1f\t\x1d\xa2n\xfcBz\x1c'
        b'A\xf60\x96\x95\xda\xbd\x9e\xfe\xa5\xf7,\x18\xb6\xb2\x02\x0c\n\xfa\x0b\xc2\x14!\x17\x10\xb7\xae\x1d\xcfDw\xc0\x86\xcdjN*\xa1\xe9\\?\xb2\xact\xd6\x96\x1e\xa2(\x94\xfdx\x8f\xd3\xc5\xe1\xebAz\x03\x98\xd9\xc0\x7f'
        b': Z\xb2\x98w\x83h\xc4|\x11\xf8\xe0j\x04\xf2K\xd2\xff\x0b\xc2{\xbbXP\x04\x820\x83\x91\xf2Q\x95w>*\x9f\xeb:\xf0`\xc9\xf7\x9c\xcdk\x8f5\xdbn[\xc9\x81\xd2\xe3E\xba0\xda\x1aY\xbc!\x01'
        b"Bg\xe0\xd6\xd0YT\xa8\x9fU\x15[\xdb\xac\xa3@\x8e\xb3\x19\xf3\xf6\xf5\xfc\x02\xaa\xf0\x1d\x16\x80;T\x8c\x12\x18\x05\x020J\xf9\xcb\xe5\x91|\xf6&'[HG\xe8\xb5e\x9d[:\xa8\xa4wb,!An\xf2"
        b'\xd5\xa86\x88\xd7M|N5\x02\x90\x00S\x0b\xbf\x95\x03\x92\x82\xa4\xa3\xfd6\rey\x04\x86\xf7\x86\xd6\x91\xdb3{\x95H\xadb\xecI\x12\xb5\xe1\x933H\xbc.\x1c\r\xb1\x85\x03\x12$@\xee\xd2$\x9br\xb2\x81'
        b'\xb9\x18W\x7f\xda\t\xda\x05\xc4\xe6\x1a\xfcvZ\xa2\x7f\x90:\x1c\xb6\xa1\xfb\x06\xb1\xf9\xd4\xba\xc3\xd5\x04\x81\x1d\x19\xa6\xfd\xef\xdd\xd8\xf1V\x05\xc6\xf7\x8fC\x05\xe1\xad\xd5+\x1f\xb7?%\xf8\x03\x06\xefx;rrs\x7f'
        b'\xec\xa8p\x12\x9b\x9eY\x8c\xebP\x16\x01!\xb8\xad\xfb>\xd4\xa6D\xe0\x03\xb15a)\x005\xd0\xe0.p\r&\xba\xf7T\xd2H\xbc\xb5.\xd9p\x0b\xee\x12$\xcf_\xfe\x11R\xaeu\x98\xf9\x80\xf6v\xc0\xe6\xa5\x91'
        b'q\x1c\xe4\xe4\xf1o\x80\x92\x87\xc7_\xfcK#}\xa0rw\xceH)G\xa6\n\xf7\xfa\xcf\xe4\xb1\xeb\r\xc3\xcdc\xbb[\xbeA.c`\xb5#9\x82\xc8\xa7\x0e\x8f\xc2q\xa8\x9d2F4\x07!^\xe5}\xa8\x93\x80'
        b'\x9f+\x95/\x99\xcdp\x9el\x13\xca\xfe\x81e\x04.b\xa2\xc0?\xdf\xc0\x05\xd3\xee\x12\xf2\xc0A\xe3\xc57\xf4\x8b\xc8S\x85,$\xfc\x0c}\x171?\x97\x9fZ \x9e\xad\xebQ\x0f\x15 \xd7\xf8\xff\xb1\xb8\xfdEx'
        b'\xc9\xed\x16\n\x12\x96\x91\xf7fj"\x80z\xa4\xdb(\x00\xed\x9e4\xec\xa6\r\x9f{\x94\xf9\xd5w\x81\x8a\x06\xb3.)D\xa1\x1e\xb5\x8a\x1e\x06\x92\x95_\xaf\x18\xb6s\xb4@\x19\xf7\xdcJ\x84~\x039\xb8\xaf\x16\xe0$'
        b'\xdc\xbf;\x9dfA\x907gC6\x1fe\xc9\x01=a\x9e\xb6\x1f\xb87:\x8a-\xcd\xd8\x0cy\xff*a\xc5=\xd3\xd5Q\r\x01\xd5\xb8,NrGL\x904\xe6\x89:\x14oj\xea\n\xfb\xe3\xc0\xb5\x08\x9a\x01\xb4'
        b'\x82W\xd7\x94}\xcfC\xc2\xcdg\x11\x9c\x03\xc0L\x98\xc0\x9a\x94`[\xcf\x10X\xd5\xb1\x10\x7f\x19&h\xb6\xdc`\xb4\xb2\xd8\xc2\xe7\xdb\xc1\x04\xfa\xce\xc1\xca\x82\xa1\x9d\xf1&#\xb6\x9dr\xb1\xed\x94\xc8M%YR\xf7'
        b"L\xb7\xe9\xbc\xb7\xd6=\xa3N\x12u\xf5\xddI9\xb4\xd1CJ\x84^\x94LE!\xa9\xcfG\xe9\xae\xafdV\xf6\xa0j\xdf\xe4\xb6-\\\xd1 X\xfc\x9f\xb1\xa8\t\xbd\x06\xd5\xa4\xcdCAKui'U\x1dW\r"
        b'r\xd8\x1c\x8f\x92"\xfe\xddw\x10\\\x92{\xfe\x80\xa6\xe6\xc6\xc0\x15\xbf\x1f\rQ\x1cI\xab^\x9cW\x97\xda\x8c;\xa4\xa10\xf1pL\xe8K\xb2\xa2$gdY\xd0Z\xa9P\x1e\x96\x0c/k\\=\xc5!\xd8-&'
        b"\xaf\xd3\xb0\xcc\xe7\x1cD\xdd7\xa2\xc3@;\x8f\xad\xf5r@\x17j\x9e\xab\xda\xfb\xdc\xf2\x1b\x87\x87\xaeD\xcf>\xb6'\xb2Q\x1f\x11\xb1U\xb7U0\r\x8f\xd4b\xaf\x1e\r5\x9ch\xa6;\x05\xaf\xdd\xc3\xdd\xd5{\xe1"
        b"\x83\x87\x1e\x12j\x0b\xa5\xb6\xdc\xc3\xc6\x8c\x02D\xcb\xe2\xf2Oj\xec>\xb4\rT\x00\x87\xd1u\xa7\x00\xef',&.\xf9\x1a\xf4\xc2\xbd?,\xe9\xcc\xbavd:\xed\x93S_\xda@C\xb0\xd0\x9f\x94n\x98\xd2I8"
        b"\x13\x03t\xe9~\xad\xab\x11\xbeo\x99\xdc\xf0'\x96\x1d\xfcj\x1c?x\xe4\xc3}.\xbc\x1c\x9b\xa7\xab\xd7\x08\xa0\xb3\xa5\x1e\x9c^N\xbd\x12Y\xb86\xbe\xea\x90\x19\x9d`\xe9,\xc2\xed\xad\xce\xe0\xf2\xbe$\xab{X\x13"
        b"\xa7:J\x9a\xb5x\xb6\xe0\x0b\xd0\xf0?\xe4\xb2\xaa/j\xcbo\xdd\x8dO\xe7\xb1\xb7\xce\x18\x88t\x08Ch\x0c\x97v1nU'\x83XK~\xd9\xe5>\xc1\xc8m\x0fCO\xd8\xa4\xe9\x06\x18[\x81\xbcN\\\x1d1"
        b"\x13\x0e\x8b)\x7f\xf0I\x8a\xd7\x17x\xfe\x0eZ}\xeaQoA'[9`\xfc\xd1o\xce'h\xe8\x8cS\xf5W\r`\x99\x03\xa8\xa4qF\x8d\x97\xd9\x8b\xad\xf4\xba\xbd\xc9?\xbay\x8e,V\r\xd1oO\xac\xdci"
        b';\x81;n4q\x17\xcc\x19\x14\x87\x82\tP\xf4\xdb\x8b<`m\xc4\x18y\xc5\xd7\xa3-#\xd6\x0f\x87\xf86\x1c<\x03|\xbf\xd5T\x0c\xe3\x02r\xf5\xcaM\x1a?\xbd\x10\x9cLm\xda\xb1\xf1o\xa3\xaf\xa2\x89%,'
        b'\xa9t\xd6b\xc9\x9ah:\xc7"\x01\x8a\x9c C\xb3-\x90\xe2\xb0\xe8\x89\xbar=\x0e\x0f\xd0In\xab0\xdf\xee\x84\xcaN\r\x1f\xeeR\xd6\xf3g\x038Y\xef\xd3\xa8\x06\x80\x95\x91\x07K8;\xb3\xfa\xaf\xf0_\x85'
        b'i\x05\xbed\x19\xbcW\x11\xa7\xc0_\rY\xcf/Pm\xdf\riQ%9\xe4\x8b\xde\xb9\x13\x06h\xd3\t\x99\x87:\xcajwD\xf3BHw\x1ex\x98:\xc8t\x97S\x8b\xed9[\xf6]\xfc\xfd\xfa$\xf5\xb1V'
        b"bo\xe1\xd2\xaf\x18\x9e\xbe\x8c\x92\xcd\t\x7f\xdf\xe2^ss \xc0'o\xe1\xdf\xc5\x0b^\xcf),p\xfa\x0e\xc1\xd2\xf9\xef\xd6\x90\x94`\x80\x8d\xa9\x01\xf5$\xfb\xd6I\xa3\x8f\x85\xf3\xcfe\xa9\xff\xfdDM\xda\x01\xa9"
        b'x\x8b\xff3\x91&q\x0f[\x7f\x03\x08\xd7w\xda\x15h\xdazm3\xf2\xb3(8\x01\xbb\x8c\xad\xa6.\x9cpXL\n\xce\x9c`\x02\xd7\xdef\x91\xa0\xbf:\xfb\x13"\xa2\xce\xaba\xcc#*\x80V.\xcf8/\xe5'
        b'6\x8e\xdbJ?\x0c!t.4\xa81\x07o\xea\xb1\x06\xa1L\xc0w\xb7<\x06!\x99\xdf684\x8d\xad[\xd9c\xa4)\x9aB%"\x1a\x9b,\xbb\x05$O\xfdZ\xa02\rX\xd4\xf4\x9d\x06\xbc1$\x8a\xd0\x9c'
        b'n[v\\\x97\xe3\xed\xaf\xf6@\xcc\x97Jfo\xa9\xa0;Z\xca(\xf9-\xba\xb8\xd0P\x0eR.2\x9cC\xf4\xf4+\xc4=)y\x0777\x147\xa2\r=\x9f\xdd\xe1\x18CW\x9c\\\x85\x15\x8a\x1bx\x1d\x88X'
        b'J\xbd \x9f\xbb\xd6\x01\xa50\x079\xc5(\xe11\xc8\r\x89%\x9d2\x05\xe2\x0c\xbf\xbb(\xdf\xc9z\x1d\x9d8\xd88\xb1R\xdf\xab\xf5\xae9 w\xe4\x92\xe4\x11\x9f\xf95\xb9H\x14\x82m+\x13tQ\xc8\t\xbc\xab'
        b'\xcf\xa0L(:5\x1f\xa6l\x98\xa4\x81\xc6\x13*\xac\xc3\x06"J\xd7T\xf7\x84\xf6\x10FRY\x9b\xf7\xcfB\x9d\xd9>\xe5\x16t\x93RWK5\xf1\xd5\x85\x01\x15\xf4\xd7\x9f\xda\xd6\xef\xaa\xc7\xe0\xcdN\xf5\xdf\xed\xd2'
        b'\xeb7v3;\xed\xf9\x03\x1f[G&\x1e\x0c5\xd5"\x13p`\xbf\xdf\xdf.\xc3\xa3$\xde\xf5\x8f1Rz\xcc\xc0\x19\xe0\'\x1f\x10\x89O\x99\xa3\x9fA\xe3E\xd2%@V\xf3V\xa9\xc4\xa8\xe3\xac\xc5\xda\xbe\xe6\xdb'
        b'\x1d\xbb\xe3Q\x90\x92\x10\xde\x19\xdaz\x01\x8b\xd5\xf1\xd8\xa4CV+9\xf6\x02\t\xe0H\xeb\xedOw6\xbb\xb2^\xf2\x10\x9fr\x9e\xb0\xc8\x1f\xe8\xf0\x1c\xfa4\x16\xcdQ\xc2\xfcq\xf6\xfdpq\x861\x17\x9eG\xcc~'
        b'\tN\xa4\x01\xf8\xbeg\xbb\x00\x98]\xeb\xf5\xebd/\xd86j\x95<$\x10yv_w\x13\xf0\xf3q*\xe9\xb5\xd5\xd9L\x08xH\xf2O\xa7\x90\x877-\xe9\xa2\x8em\xda\xd2\xae\xff\xe9\xb5\xfc\xed%\x93I\xfb\xbe'
        b'e{\x9f\xef\x85\xf6\x1cSB\xb65\xbe\xef\xba\xbe\xd6r\x01\xc1\xf62U\x80\xd7\xe6^w?|\xbbWD\xedN\xb4\xd4\x1d\xc3\xf5\x05;\x14\x97\x05\xd8\x0fD\xb7\xaf\x95h\xf0u\xce\x1d\xe0q\xe7\xad\x7f\xf6\x87\x1c\xff'
        b'\xcb*0\x9c\xb7\xf9\x9e\xd8\xd5\xc2\x0c}\xcd\x15\x98\xec\xff\x9d\xf3\x06?\xe5~4\x82\x87\x80\xa8\x02c4\xa3\x96\t\xe2\x895fb\xd7\x02\x0f\x8b\x00\xc9s\x16c\xf7j\x98\x7f\xe9\xbc$e\xb3Z\xb1?\xde\xcbPA'
        b'\xf2\x15c\xae\xa4+\xdc\x86\x93+a\xbb\xa2|\x9aV\xc2.\x8e?1\xbe\x07\xbf\x1b\xdc<%\x94mX\xe9\xc2\xd3\t\x88\x8d\xd2\x9e\xfca\x90@H\x13\xe8\x1c\xab!8L\xae8C\xb5DZ\xc2\xa4\x97\xd6\x1b+\x06'
        b'\r\xe5\xbd\xc8\x89\xb9q\xd6\xe5\xe9\x10\xc2\x98\x18d\xe2L\xc3\x93&\x14\xdePt\x8e_\xc4\xe6\xa2z?d\xeb\xb5\xab\xbdY\xb2\xb9~\xa68\xb7F\x0f]\xec\xbct@\xef*\x0b\x040\xc33\x02\xa8\xf4\x7f\x85H\xd8'
        b'\x94\x8dO<\x01u|,/\x96\x15\xf7`Q\xff0\x05\x86I\x97\x19\xdf\xc0P\xb3{]\xc1\x9e\x1c\xdey\xaa\x08\x91&.0\xa7\xe7b\x01\x16\x8b\x01\xe2\xa2,\xcdR\xa2\xd661f\xf4K\x07q\xd9\xd4\xef\xb9\xb1'
        b'V\xc1\x19\xef\xca\x89\xdff\xf5\xaf\x14\xc1 Z\x87T\x91\x90\x8d\xeaf\x14\xe0\x03k\xa9c\xcc\x89_`\x1e\xcdK\x9d\xf9[\xb6.XT\x00\xa0\xf8\x81\rW\xf2R\x1b2\x00\xdb\xc6\x11\x10\nLG\x0c\xab\xb0\xab\xe1'
        b'>\xed\x82\xa8ib\xfd\xd7H!\xc6\xdb\xbcP\x88\xa8\x80\xb3\x15\x98\x0cyH:3\x00\xf7\xb6G\xe0Mgly\x13o,\x17$\x7fW\xff\x0f\x8d\x11\xe9\xadH\xcasl\xb2=5\xd8\x05\xe3\xd4X\x1f\x0036\xd2'
        b'\xf1A\r\x85]A\x08B\xfe\xaf\xea|n\xa0\xc68U\xef\x15~\x90{\xf8c\xcd\xc4C\xbd\xc6\xe1\xd4\xdb\x89\x84\xad?\xa4\xb5uW\xe8\xda\x8c\xb8o\x0c\x01\x7f\x9b\xebe\xdc\xe0\x88\xce\xe5\x9b\x84\xf3VI\x85\xe4\xad'
        b"\xfa\xccP\xbc'\x851\xc1\xa0I\xe5\xe0h\xb8\xd3+\xcb\xf3\xdb\x82r\xf6\xd6\x93g\xf5\xd3\xe0\xca\xbf#B\xcc\xf6~W#\xb7\xb6CY\xc2\xd2M\x88\x06\xf0\xdb \nO{\x0btM[VS\x1e\xbb}R\xe9\x80"
        b'k\xfbU\xaf#)\xea\xe2\x94\xc5+\x000\xb5\xd5"\xbby\x8d\xa0\xcc\xc5\xa0\x10?I6\xcc\x83\x00\x10\xd5\x9fL~m`\x9b[\x91\x9f\xa9\xe9\xda\xe7\x82\xfd\x94\x04u}2\xe4\x9bDU\xd6\xaf\\\x108\xdf\x93\xca'
        b'\xf7L\xc7\x0bM\x04bO\xdd\xe1Q\x17\xca\x1fL\xdc\x85\xd5\xa9\xe1\xe0\r\x17\xafK\xb9A\x0c\xe3\x08\xdeN\xc9\xb8\x94\xf4U|\x8aH\x81\xe1\x05\x91\xe9\x03\xc3&\x9a\xf1\xac\\\x8c\xf2\xcch\xads\x14\xb4\xd6\x84\xad\x8b'
        b'RV\xe9\xac%\xe9\x92\xee\x15\x19\x92S\x8d\x89Y\xca+\x9f\xfa M\xfe\x0f\x7f\xbc\xd6\xd2_\xdb\x97\x04Z\x88N\x95\x05\x80\x08\xf5^|\x04b\x04\x9b\xc4\xa1<ef\xf5\xb2\x13\xed\xd0,}\x88\x91\x1a4\xe3\xc0`'
        b'd:G\x08:\xb5t\x95\xbc8\x19\xd3\x16\x980-\xbb]\x97x\xf4\xeb1\xf1\xfe\x8e\xfb\xa9\xff\xf65\xfb\xe9\xeb\x87\t\x0b\x1ah\xc0o\xb0\x9cn\x05J\x8a\xa1\x16\xe8\x15\x91\xae\xd3\xc9\xcd1\xcf\xa7\x92{\x07\xa5\xa8'
        b'(\x89`tJg\x8e\xfa\xc7\x02\xc1\xa6\xfdV\xb2P|oX\x94\x12|\xb2\x82\xdf\xb6\xffz\xfb~rh\xb3~\xf0\x01\x16\xc1\xd4\x07\xbc\xdf\n\xef)u\xc5t\x1eI?L{\xe7\x93s\r\xfeK\xd3\xe8\xf1%\xe1'
        b'\x94\xf8\x0e\x9a\x04\x0e\xa5\x8d_V\xac\xa9(F\xa8\x15m[=\x9c\x8byNHuw\xb1\x0eYe\xd9\x12\xfb\xd7\x96,\xc5O\xc7jM\xa0\xa0\xbb\xad\x870\x80\xa0\x92\xd6\xb8bN9\n7\xb5\xadY\xc3\x11\x00\xca'
        b"\xd7\xbd\xbc\x10?\x9d\xb71 \xae\xe3v\x14q\xe99\x0b\xc4\xcd6f\xdbA\x0fTFh@\xd8I\xd9\x9e\x1cjm\xdb{/\x11\xc9'4\xcb\xcb\x98\x03\xb0\xa1\x14UPs\x82\xc6\x0eNc\xdd\x08B\xfb\xdb\xd2\x1f"
        b"t\xbeu\xefO\x11\xe2D\x8c ]\x03\xf99\xb4\x95U\xa6\xb3\x0c\xb9w\xe8'gw\xcc\x1f\xcc\\2\x1c\x0c\xf0\xc0r\xe9?^x\xceD\x16\xcd\x99\x0e\x0f\xe8w\xaa\xf0\x03\xddj\x01\x8e?'\x14o\x0c\x14\x83\x16"
        b'\x8c=\xd1\x8d4\xd1\xc7}\xe5lf\xf3F\xb2\x17\xb1$al\xa2|\x8d\xbd\x08\xef\xa2\x16{_\xe0\x08\x1bR}\xb1]\xb5\x1c\xc8\xc3x\xef_`\xb8\x0eA\xabS\xe0\xde\r\xa4\xd1\xa9B7\x12\xec)\xc2A\x9f\x85'
        b"\x9aYx\x956\x00\x06\x8a3[\x05\xf9\xf3V\xc2\x1dd\x83\xb2\xb7\xb6P\x9f\xa0+\xd0\xe2\xcf\xaea\xfb\xbb\xdb\xa6\x85},S\xc0]\xb1\xbb\x9bB\x95@\xac%ZP\x01\xab\xab\xd7\xed~\xd1'\xdf\xdbb&4\x19"
        b"\xf6\x1f8\x06\xd8\xa3\xacD\x03o\x1a\xdb\xe6?\x11j\xb1\xa1\xc5\xc1Qy\xba\xdb\xd7\xcb!\x0cE\x1eax\x0c\xf6\xc8o\n\xc7{;\xa1\xff\x82\xc8O\x1c\xc2Q\xdaQ\xda\xa4Y\xd1WX\x0b\x8d\xd8\x14\x0c\x03 '"
        b"\xda\x99?\xe8\xb5\xcd;\xb9&\xa6\x19i\x9c\xfa\x02knF\x95\xca<\x88\x18\xdd\r\xa5\xd4\xb6\x842AK'a\xed\x89@\xde'n\xf6$\r\xa9\x00!\x9c*d*\xac\x1d%\xeaI\xa1\x128{\xfb\x86\xee?\xea"
        b'\xad\x17\x8b\x88|I\xdcA\xb3\xa7\x9f\xc9\xe2\xa5F0b\xb9\xb3\xa3\x17\xe8_\x88w\xa5\x99\xef48h\xef\xb7L\xee\xae\xcd\xbd\xd1\xf5\x08\xfdq\xcd\xeb>Y\xa9\xd4$\xcb\x18hMYM\xb0vp\x9aS\x17\x9f#'
        b'\x8ey\x86l\x8eIp\x12\xcf\x94"\xe6\x83\xf6NB\xe1\xd6\\rR\x15\xf1\xba]\x8b\xfc\r\xd5\x98\xb46\xbd5o,I\x05\x8dX\x15\x8cdx\x94[D\xfcWD\xb5\xd9,\x0b$k\xd0\xf9\xb9\xdb\xa1\x07\xb8\x98'
        b'hj\xef&\x85\xa9\x97\xa24\xc7\x026\xa4\xc1\x8eU\xb0{\x99\xa8}\xe5\x84\xe5\xec\xafeu6A\xf6\xc1\x03\xa5@\x9b\xbd\x8blo\xd0\xfe\xed\xf1\x0f\x1c\x81\xe3\x9fLF\x19\x00D\xbc\xadC\x13D\xc3w?\xc5\xca'
        b'Z94e]\x8b\x1b(1\xf4\xben\xba\xf1\x83,\xe9\xc7e\xd6r\xd0\xd6\x84Q\xfb\xc407yK\x0eX\xd2\x10\xd6\x06,v?\xae\xbd vv\x14\x92[E/\x1c\xfa1\xc6\xd6\x95\xc0\xd6\x8fr\xdf\xbb\x19N'
        b'\x88\x8fr\xb0P\xaa\xe83}\x981\xf9\xf7\xd1\x90\x19\x1b\x00\xa4\xe2\xa1\x91U\xa1\x1fM\xcb\xe7\xd3\xa9\x08|\x13\xfe\x91{!+Mx>XX\x94\x13\x9cf.\xfd\xc7~\x04?\xbc\x05\xe2\x86\x01\xa7\xe0\x17\xd7\x0c\xcc'
        b"T1\x0b\x13\xa2\xf4\xb1/\xe0\xa8\x85(IV\x8cG\xf8'\xcd\x17\x1c\x86\xc8\x1e\x03%\xa8\x16\xa8L\xe34jI\xf5\xcd\x80\xd9\x97v\xb7\x97!N\xbb\x95\xed\xe4\xfbF\x89f\xc02;\x1b\xad\x99\x87/\x00obx"
        b'\xc0K3\x04\xb3*[\xf7D\x05\x92\xa1zM\x8f\xce\xdf\x94\xa2\x11j\xa4\x8e\xfd\x89+\xa2\x98\xd5\x11\x84\x88\x03\x83\xaa\x92\xd9:\xffry\xc9=q!\xf7G\xfa\x15CA\x8d\x1d\x8f\xb8\xad\x8a\x00\xf3\xa0&UA\xc0'
        b"\xf5\xec\xdb1\x1f\xb3\xc3\xfcG#\xb5\x03\xa1\x95n\x00\x14\x92j\x17\x07\x0f\xb0Sj\xf1\xd2T\xfe9\xad'\x16\xa8\x06d\xf4\xa0\xb3\xa1\xf8Z+\x8erX\xdd\xb0rT\xc98\x9c\x0f\xce\x00\xae9\x02\xce\xaf\xd7h\x1f"
        b'\xcfBdt\x92\xfe\xcah\xe4d\xc7A%\x88\x93\xe2q\xcf\x8ai\xc3;v\x83\t1\xf4v\xf0\x87\xa6\xfe\xa82\xfe}\xf3\xc0\x19\x04\x8ft\x96\x93KA\xa2e\xbc@\xf1rm\x93;3\x03\xf2A\xadP\x1dA\x0b'
        b'\xc7[i\x1eFY)m\xd0\x9d\x00j08:\xb0\xb4\xff\x01\x17@\xf6\xa08\x80z6\xcco\x89\x12\x8d\x07\xd2*\xad#L\xcbR\t\xccd\x80fu[2\x16\rn\xc5\x8141h\x8f\x08\xb4\x92\xac#\xd0\xf2'
        b'\xcd\xe4\xec\xfeI:\xc3\xde2-E\x8c\x83\x9bhRX\x8d\x0c\xaaS=>,\x07\xd3_,\xd1\xdc\xee\x0b\x92\xba\x0f\xa4\xbbl"&\x0bj\xfb\xdd~\x80\x80kC\xa1\x87\xaf\x97\'\xd8\xd4\xc3U}\x99c!iq'
        b'-(\xabJ\x1b7j\x99\x10\xd8n\x04\xbeV\x17\xd3 +hl"\x1b\xf3a\xff\xe9\x05\xe4\xc4CgqML\xeb\xcb\xe6 \xb9\x8a*\x05^\x85\x03\xae_\xf6\n ~B\xc5\xd2\x97\xb2\x9a5JP\x89;\xfb\xcb'
        b'\x05\xb9\x9b\xeeW\n\x03G\xfaPh\x96\xb7_\xf72\nM\x9c:\x93\x11EBi\xc1\xbf\xc0\x11\x92q\xce\x882Ob\xaf\xfb\xb9\x11\xd7\x1f\xbb\xf4~\xe9\xdd+]\xaa\x1f\x0b\x86\x9f\x0b\xf3"v\r\xe4\xb0\xb3</'
        b'\xe0\x01\x85\xbd%\xd8y}x\xf0\xc1o\x17\x80\xad\x0b5\xe5\xcd\xc2\r9\x83\x0ep\xbcqA\xc0m\x18\x8c7\xb5pXcUpl\x10\xa59\xc5!\xdf\x9e\xb6(\xc3\xe6*F\xd3m\x94v?V\xbb\xc8N\x02\xb5'
        b'\xbc\xb6\x84k\x9c|\xd8oz\x8c\xbd\x17\xbe\xe6|g\x8d!\xb3\x9bAwS\xa6\x13\xf7\x1erW\xf6\xcf`\xf5\x1e\xc4\xd9\x9b\xdf9\xb0%I\xc5`~:\x88z^\xf0\x07\\!|Ax\xcc\x81O\xf0\x8bE\x08@'
        b't[U1-C\x00R\xb7q\xef-\x9f2\xcaZI\xab8\xb6\x0c\x837\xfc\x06P#\xd9\x0f\x07\xbd\xa7\x85\xaaT\x7f\xc3i\xe3\x9c\xcd\x19\x952\xf4\xb5\xac)\xb0Up\xd9\xe4Q\xe2\xcd7\x06\x14I\x8c\xaf\xf0M'
        b'X\x8c\xce\xe0\x0b{\xb9;%S\xb6\x89\xa7\xc3\x1b\x1d\x94\x8a>\xe1\x94x$s;\xc2Z2^\x16=\xc1!$\x12s\x92\xbdtv\xfd\xe5\x04\x94\xb2\xb9m\xb8\xf4\xba}\xb6\x8d\x855<<\x11\xaa!\x83m\tx'
        b'vFHY\x06\x12\xbc:\x9d1\x08\x0cV\xc1\x95\x94\x04\x8e\xa9_\xb8\xa7\x06g\xa1\x1av5\n$\x1d\xd5%,9\x05i\xc1\xc8\x82\xc4j\x82\xdf\xef\r\x9e\x1b\xfa\x9a\xe7\xc72\xc6\n\xad&\x1c\x0euc(\xaf\x8c'
        b'\x06rv\xd1\n\xaf8?\x10\x88\x00\xf7\xd8\xad\x1fo\xb9\x9f\x14\x19\x97\x18+\xab\x08\xddU\xe9\x0b\xf2\x92u|\xc1\x08\xc8\x10!GF\x84\xce\x96\xa7|[\xad\x8fiA\xb2H\xb5\\n\x876\xf8{\x7f\x85\x93c\xa4'
        b"\xf4\x19\x8e\xe4\xe9\x01N\ns\xf1\x8c\x99Iv\x7f\x9b\x16\xb7H\xf1\xd8\x11\xdd)\x1aaK)\x1d~k\x00\x9f,\x89P+v\xa7\xb6\x02)\xba:\x05b\x15\x12\x1fbb\xd6\xb4'\x97\t\xaam\x88\xf0~\xc2\x16&"
        b' \xa4\xaf>`\xfc$\xb7\xec\xa1+\xa0j46q-\x1b\xce\x86\x0e\xad\xf7U\xcf{#\x14y6\xb6, \x91\xa51\xbc\xbe\xd6\x16\x97I\xd3\xab\xdb\xd0\x02\x89Y\x17dm\x85\xfb\x1a\xf3\xfb\xbf\x05xQw\xa1\\'
        b'\x98\n\x17\x18\xa7\x91x\x819_\x048VAjc\x90\x9b\x93\xd3\x02\x04\xc6\xe9&\xe7U|\x1b\xd5\x15\x0e\xbc\xb9\x0c\x15\xaawG5\xf0\xb3V\x12\xfd>\x9e\xbdc\xdf\xcd:"}\xb6\xd2r\xa5\xe9%]\xce\xe3\xa0'
        b'\xbd \x7fQY\xda}\xb3\x9fNL\x98\x15d@\x12[[\x01\xa5\x819\xc8\xc8\xb7\xe3.-\xeb\xb1\x8f\xdf\x91t\xdd\x9a.\x08\xc9\xd6y\x9a\xf4S\x1e{\x9dy;\x1f\xf9#\x96\xdc\x1a\x98|dh$q]\xb3\xe7'
        b'\xec\x17\x87\xb9\xa7\x9f\xb9\xdf$G\xeaeZ\xa9I\xad9\xfa5\xd6\xedu\x16\x8d\xf7p\x06\xd7\x14S\xff\x9f\xc8\xd9E\xd4\x97\xc8\xca\xa8\xe9\x8c\x8c{\x93\r\xb9[\xad^3\x98\xfa\x8bm\xb4Ns\x7f\x8fng\xcb\xf4'
        b'\x90\xb2\xee\xf7\xdf @7mE\x9d\noig\xa2\xc0\xb3n7\xaa\xe6B\x1b\xec\xa6\xa5\x1a?\xeb\x123\xe4^\xa1\xb7\x94C\xaa[\x11\xb7\xb3\xc6\xb0\xe1{C?p\x96\x9d\x8bG\xadqmFPw\xa7\xc3\x1d\xc3'
        b'PM\xed\x05&\x96U,\x8f\xb9\xa8\x1a\xadX\xbdD\xa9\\\xa2\xd7-\x157\xd7P\x88\xe0\\~\xa1\xa5\xbc\xcbD\xa2\xf1m\xd6,l\xacJ\xe5\x9d\x0f\xe0\x08h\xb8!\xb1\x84>\xe2h\xe8\xea\xef\x8f8\xc9\xc1\xd5q'
        b'\xba\xae\x8e\xbb\\5e_\xda\x01\xee\x9a\x8d*Xre\x9d\x12c\xed\xd5\xbe\xb5\xe4%\x82\x9a\xf4\xf6tg\xf9\xa9l3\x19\xac\xf6\xb9\xc8\xa4\x01\xe5r\x97\xcbF\xe5\xb3\x8e\xad\xb4\x9b\xc3\x83\x15\xb9\xe0\x12;\xba\xa9\xe4'
        b"\t\xab\x90,{\xb7f2\xe7XkZ\xe2\xbbj\xc2\x1a\x93\xb01\xec\xcf\x00\xc9\x92\x1e\xf0>\xa6k'\xd4\x08\xebz\xd0:\x96xn\x12T\xba\xdc\x93\x8e\x8ah\xc3\x05\xff?3`z=p\xda\xce\xe4m\xd8\x95\xd4"
        b'+\xe6\xb0i\x13\x886f\xbf\\V\xa6k)\xb5P\xa9q\xc7;\x98\x9c\x8c\xa97\xdf|\x01\xe5\xdd\xc6\xa9\x0e\x97h\x0c+\n\x1c\xdb\x9d\xdaw\xbf\xa5\xa2\xa6O9\xac\xe2L\xc7w\xf42\xfc\x06+\xb1to\xa7\xfe'
        b'\x90\xc6I\xa6\xde]\x8fp\t]%\xc2\x80\xd5\xd5\x9a\xd4\xa1\xa7]-d\x99\\\xe8.\xf8\x97\xeb\x8c(\xe4/x\x85E&\x12p\xa7\x00\xd54\xd4\xca\xf2e\xffc~_\xae\x18\xffg\x1a\x99~\xc8sE\x99\x1a\xcf'
        b'>|\xb9K\xac\xa9$\x7fT\xa8\xfd\x9c\xb3\xd0\xf9\xd9\x06??4\xcd\xff9\xbb\xfb"]\x0b\xa4\xf3\x0ep\r\xa0($\xea\x9cKv,;\x1d\xaa\x8e}\xa6.#l\xeb\xce\xee\x81\xf1\x0c1\xad\xa0\xfd\xe9\x89\n\xaf'
        b'\xe6\xef_;8\x856E\xf1\x06\xa4\x8c\x0b\xf4\xc0\xb5\x93\xd0\xd1\xf5\xe4\xe5\xb2M\x83`a\xa8\xb6h\xf6\xb7\xab\xe8\x8e\x9d\x13q\xf6\x8a\x83\xf8\xc5\xd5\xc2q7\x9e\x86\x93\xb5\xe6\xee\xca\x17\x95,\x05\xa0l\xd8\xf6\x81Q'
        b"\xde\xe5\xeeOR\xa5\xf0\x81v\x0c*\x82\x9a\x18t\xd4uLb\x8d\x0f\xa6\xde\x7f\x1aN\x1f-\xc6\x9b\xe8\x1c\xb0\xaf\x03>\xce\xae\x8a\xe7e\xdf\xea\xe5'\xb6\xb7\xd59\x85\xdd(\x9bBA\x03T\xaeY>\x1e>\xe1\xb5"
        b'\xfc\x89\xbe;*,nR\xf39\x9a\x0c:\xf4\x80\xd9\xf3\xc4\x06)B\xa7C\x03C\x12\x16\xb45q\xb4\xbf\xc18J\x88\x1cnK0\x12\xeaMeG\x94m\x10\x8d\xbfQa\xf1\xad(v\xbfM\xda^\xba\xc8\xbcQ'
        b'O \x9bm\xf4qO\x91Q\xeez\xfc5\x08~\xe9~\n\xeck\x18u)o4\r7\xd3\xfa\xce]\x90\xf3D\x01\xfa\xc8\xeb\x1cKR\xde\x9bV\x9e\xfc\xcf\xfb\xe9\xe5\xf2(\x105t\xec;\\\x13\xbck\xa7\x02D'
        b"\xaaNS\xb7\xfc\xd2$f\xb2;\x9c\x05\x15\x035\xc9\x04W\xf2'\x18\xcbc\x19\x97\x8f\x1aO\xaf\xdf!\x18t -\xf2\xb2\x019\xb1HBg\n\xec\xd6G\xb0q\x1c\x05\x8b@\xa8K\xd6\xa5\xbc\xa4\x9c\xf3\x12;\x06"
        b'\xf2\xd5?\xaf\xfb\x04-\x82\xf9pLR\xd4\xa6\xd8[t\xdeE\r\x01,DfP\x8cd\x1c*\xa6$\x16\xe7r\x99\x00O\xe4\xb1\xc5\xbfH\xa1\xa4\x10\x1eq\xc1{\xdbW!\x15\xab\x1d\xd0\xa7~\x93\xa5\xe3\x7f\x00!'
        b'\xee\x1a_\xfe\x9c\x90\x81\x1e}f\xcd\x15\xe6Fzj\xd1\xefL\xee\xe2\x11\x98r\xf9\xc8\n\xc1Ola\xd1\x89z\x84\\\x1e\x8f\xde%C\x96\x8dC\x16z\x17\xb5\x1e\x89X\x1c\xd1\x8eG\xd8\x01\x1c\xcd\xd06\x9fLy'
        b';\xf7\'(T\xe4\x1er\x15D\xf9\x02\x81\xe3@A?\xb7\xc8\xbb\xc7~,)_\r\x92?<\xe8$\x98\xc0C\xba:\xa3\x9c\xc7\x08\xa6T\x13\xa3\xafb\xbbY\xf3R\xa2\x14\xf3\xc8\xd9\x89\x0f\x81^^7_"\x8a'
        b"J\xcf\xf9\x85\xd65\xcay\x94\x14S\xe6\x8f\xe7Y'\xad_\xd0\xfe&\xdb\x9e\xf6\x9cJ\xda\xb1\xc9\x9ds\x9e\x92\xf3;\x06\r|;m\xfcr%\t\xf1pt[\xce\xde-W\x86`\xc7\x1b.\xd1\x8a@\xab\x03\xb2\xbb"
        b'\xe7\xc6p|\x1b$\xc8\x83\xda1\xd2\xb5\x1aI\xf9\xed\xa21\x97\xeb\xc0?\xe7y\x06\x16=\xc1TR\x1c5\x19\x9c\xa7\x99\x9b\xafB\xebR9\xcf\xbdn\xc4\xa4S\xcd\x8d\xaa\xa6Rs2}\xe1\x9f\xc9MBR\xe3\x8e'
        b'LuV\x02\xf1h\x8c@$\xab5\xd1\xe5\x9ce?\xe3\xf9~\xf6\xea\xee\x81\xa4\xd42\xaa=un\xfe8\xe7\x1bh\xb0*H\xb2\xff\xee\xa3\xf7Z\x0b_\xa4\xa2\xec\xe1F$8\xee\xbeal\xc5\x1e\x1cu\xbe>s'
        b'\xe43!=g\xd5-\x00\x05\xb2\te\xdd\x01\x1c\x0cb\x90\xfdA>\xbah\x82TU"\x15h\xfb\xaa\xa4|\x1f\\\xa9\x7f\xe2\xae8x\x02\xbf\xf6o\x89\xdb\xe7\x80\x8d\xa5\x8a\x8c\xbd\x01\xe5\x17HK\xf9\xd5\x831\xff'
        b'\x1d@\xfc\x13\xce\xca\xa3Yk2 \x05\xa1A4\x1e\x81)\xb8G\x00\x0b \xb7\xaa\x1ccU\x95\xf9B\x14\xf3aEF\x97\xc2M\x14\x9f\xd4\x1b\x13\x96E\xca\xc1\xbe\xadQ\xde\x1f!\xaa\x15\xae\x04J\xb9g\xc2X\x90'
        b"4\x08m\xd5\x96\xe0\xdaH\xea\xd1`\xc2=\x9d\xc9F9\x07\x82\xe1\x8d\xfe\xad\xd6\xfd\xc6\x11\x92\xb4\x07\xfd\xc0\xaes\x98?Y\xda\x12\xa3wg\xb9\x93\xa9\xe1Oz\xb8\xc5Y\x06\x841\xf3\x1e\x08'\x97\xa1\xd7c\xc10"
        b'\xd8\xa3\xdd\x9c\xeb\x13\x87\xe7v\xcah\xb0\xcb\x9e\x17L\xa0\x02\xbd]zZ\xf7^\xcc^\xf2\x7f\xf6\xf5\xb3\xda^\xf6\xd3i\x0b\x85\x81s\x05\xdc\x8b\xd5`\xc9\x13E\xa7\xc4\xdbv7\xfa\xcbA\x8a/|__\xb9C\xa5'
        b'\x18\xa6&\xee\x88\xc4v\x86uz\x84\x04\xc0\xb0\xd8\xa9\x80\xfa\xc8\xb0\xb0\\\x9798W\xee\x96b\xe6\xa3,PC\xa6\xd2A\xab\xa4\xef~a\xc1\x84\x90\x15C\x17\xcdy\xba9\xc2N\x028"q\x9e\xb1K\xda\x8a\xa9'
        b'\xcd,6\x8b\xcb\xc6\xb6K,\x8a\xd0\xd0o\xac\xb4\x96V(\xd6B\xee\xeb\xban\xfbl\xcb7\x14\x15F\xd2\xe8M@\xf4`\x85u\xf2b\nk\xa1\xde\\\x9a\x01G\x94a\xc0\x0f\xe6I\x18%\x82\x12D\x9c\x1e\xfc\xc5'
        b'\x9brKO\xab\x11\xc2=\x9f\xf6\xaa!\x00A\xc2\x99\xf0\xd4\xeea\x1d\x96\x8a\x0c\xfa\xc6\xf6\x173\x9e+\xb5Q\x84\xf0:\xfc\xd6^\x9d\x99\xa2\x0f\xc2\x8e\xef\xd5c<*Z\xc4\xcd"~\xf4]\x9c/\x8b\x83\xde3v'
        b'6\xae\x89\xc9b\xb7\x8d<\xea\xb6\xddV#n\xa7y\xba\xba|+CF}\xd7\x12O\x05G\xc7\xb1\xff\xcd\xa9\xef\x8e\xef\x7f\xdd\xe0-\x912K{\xb1u\xbe\xc4\x7f8\xf7(T\x95?\x1fY\xd2\x1e\xd3\x8d\xde\xfb\x9a'
        b'\xe1\xb8[\xb9/(->\x8a`2a\r\x9f\xd4W\x84\xb1\xed\xcc\xa6C\x9a\x9fa\xb4`7\xd1\x8e\xba\x0f\x8e6rh\x1f\x88\xd1\x82\xcdR\xe8\xb5\x0f\xfe-\x88\xb2\x02G\xb2`{\x85\xa0a\xa4W\x16\xa24\x96\xb5'
        b"\x94\xfe\x96BO@\xda\xd7\xdbH\xd1\x0eC\x88\x19\xdaRu\x99$\xd5\xdd4\x1d\xb1\x8b>Xw\x04\xce.\x04oR\x9eW\xd9]\xd2i\xd2#X\x0e/\x1f\xd0\xe8'\n\x0e\xdc\x8e{\xf3F\xbd\x8f\xd5\xecc\xeb8"
        b'O i\xc5D\xb5\xccK\x10\x8bs2\xe4^9\x84\x1f\xf4EVQ\xa0\xa1\x97XD\xe6L\xbdy\xb7\xe2c\xa5\xa6j\x10\xe0p,6\xff\xf9f=\x12m\xddy\xf8J\xccW\xd7=\\\xf3u\xd1\x16\x9a\xaf\xb8\xe1'
        b',\xeb\n\x08\x05\xde\xae\x81o\xeb$\x91pf\x12\xb4\\xL.\xd0D\x89\xf3\xf4\x12\x1f\xef\xaew\x08\xad\x1e\x95\xad\xf3\xe6 \x1a\xf2\xd1\x15\x8f\x86q\x19\x9b\xdd\xbc\x00\xc3\xcb\xd9\xf4&\xb7\xa1\xe4`&\xff.\xac,'
        b'a\xd9\x8a0:\xb6a\xad=\xf2Z\x1a\xcb\xadG\xcd\xaa\x7fe\xe89\xa2\r\xb8\x0f\xf2\xe90"L\x825\xbd\xe4\x8eY\xb2h\x1a\x9f\x13\x19PW\xb4\xa6\xd4\xf4HR\xbb\xb6,\xba\xc9\xd6\t\xef\x08\x1c:\x14B\xa6'
        b'\x1e\xb3\x07\x8d\xb4\x06\xdc\xcd\x92\xe8[\xdf\x1a\xeb\xbf\x9d\x8e\\`O\xcc\xc0\xdb\rt\x18\x14#y\xd8\xdd\xe0\xc6\xb4u\x83\x1e\xb5\xc8\x8b\x1e\xeb \x9f\xcf\xdc\x11\x05\x0b\xa5K\x18\xcc\xde\xb1\xd4D\xf1\x11\x13\x84\xca\x0f6'
        b'\xb8\xeeN\x18_?\xb9/\xc6BA\x7f9\xdb\xa2\xea\xb3m\xbb\x94\xff]$\xc2\xbe;U\x0em\x8bA\xc7*\xa1^\x9c\xbd\xc5\xbf\xfa\xe0\x11\xeb\xb1L\x06P!\x8c\x1d=g6{L\x96>\x94\xf2\xe8\xe8\xe9\x92\x8e'
        b':\xd52@\x8e#^\x8cH\xf0Mp\xce\x91\x1f+\xa5Lh0;x(\x9a\xff!+\xb29\xf7\x9c\xe0\xb7:\xd0\xb7\\\xa55\x8a\x96\xeb\xfe K\xd1Y\xaf\x7f\xaf=\xb0\x845\x1a\xbf\x0c)\xe4\xe7\xf0\x123O'
        b'\xe2Ub\x8f\xed^\xf3\x0c)\xf6\xb0-O\xa52w\xb1\xe8\xcb\x8d\x0b\xd4x\x1f\xb2\xbf\x11\xee#\x89\xb3\xf8}}X\xc4\xd0\x95s\xe1\xd0b">\xef4h\xb6\x94\x0b\x9dU^\xb5\xafO\x1c\xaf\xe7Yy_\x9dC'
        b"\x16R\xa7s\x9d\xa7<\xc8[S\xd16\x19\x0f\x8c\xb0\x9fk\x82\xaf\xccx\x7fb\xff\x81\x14\xc2\xf1\xa8\xfc\x83\xacA\x87\xaet\xffT\xa0\x04\xc0)}\x1eU)\xfb3&\xeaAn\xf1'\xbc\x8d\xa4\xd7R\x8e/n\xcd"
        b'\xdb\x12\xe4\xe1\xcc^\x0f\x931|*x\xac E\x12\x99\x81M\xa8\xb1KW;\x0c\x14\xfd\xf1\xb8\xf4\xde\x82SP\x19\xa8\\\xc6\xb9@Bw# \xeb\xe1\xbf?\xe5\x80\x13\xa4\xb0U\x11\x17\x12sOss\x93\xf6H'
        b'\x99$\x186\xa4\x08\xcd9\xde\xb4\xf0f3\xdaw\x97\xc32\x82b\x1aJZ+\xcb\x7fj\rV\n\xdaP\x16\x81\xbc\xb3=,\x81o\nXNx\xa1:Od\xfb\xcc\x19P5\x96\xd8#\xffi^Y\xeb\x08\xc7\x0f'
        b'/2R*O\xb6)0\xd2" m\xcd\x89/XQ\xa6\x11\x8a\xbd\xe18R$q`V\'=@=\x7f\xc3B\xeaG\xb6\xf3\xec@\xd1T\xdd\xcaS\xaa\xc9(\x13\x13\r\xd4%\x03\xe6\xa8\x06\xa2\xdb\xc8h\xe5z'
        b'j\x93\x0f\x0cw\xb0@\xaa\xdd\x04"\xb2\x98\xfd\xe9\xa2\xaa\xf0\x12\x8f@\x96\xab\x923jw\x05\x90\xc3\xa2 \xf0N@\x8b\xe8\x1e\xaeG+\xb5bTXp\x83]\x9cv\x0e\x8bPY\x1d\xc7\xd9[\xab\xe9Ow\xe8\xab'
        b'E\n\x93\x08{\xb6\x00i\xb1\xf8\xe5\x11l\xde\xc1>/\x1b\x1c\x10\xd8u6\x04VF\xc5\xa8\xf5\x9d\x98B\xf7\xcbG5v\xb1\xe2\x18t\xd4\x134.*\x836\xfc\xf2z\xd9).\x8e\x9fLl<%\xdb\xc8\xc7#'
        b'{\xa3\xd1[\xe5a?S\xa9\xb0y\x80\x93\xff\xc2\x1d\xf4\x82\x05\xfe\xdce\xf6\xf2\x80\xecp\xf9\xbf\x1ex\xc5o\xd3\x01\x98.\xcd\xf9\xc1\rBYw\\m\x83\x17\x9bP\xfc\xc1w\xdc\x0e\x10Pg!/\x91\xc4\xffv'
        b'O\xef2.\trU\x7fTz\xdd\x8dDqK\xba\x14\xc0\x9c\x16v\xbe\xea\xea\xae<\x8b\xb8\xa4p\xf9\x12\x94\xf2\x1bt\xb5=\xae\xd4\xfeu+\x14\xe4\xb0\x86{p8\x8fo\xd1\xd4m\xf0i\x85\xfd7S\xd2\xedq'
        b'F\xdd\xeb\x0e\xcc_E6J\x11\xc3\xdd^u\x81><\xe9\xfd\xfeHn\xab\xf1\xc6\xe5\xa8\xec?3h\xd2cz;:6\x98\xf6\xb7\xdd\xa3\x8ez\nH^\x9b\xb8\xd5\xd8C\xa3\x95z:\xee\xaey\x07\x1dimY'
        b'B\xe8[*\xf56U\xcf\xb7\xffw\xf4\x0e\x19\x86\xae\x08\x89IgJ\xfemP-\xc9t\x8c\xa3V\xa8\x12C\r\x0c\x95l\x1b"\x91<\x9e\x9a\\U.wQ\xfc\xf7p\xcaX.\xa8\x89\xb7:\xe3\xbfs&6<'
        b'\x83J\x9c\xe3\x99o\xd6\xee\x91\xb9J\xee\xd0\x93K\x87A"@\xd0:?\xb7LpEEGe\x92*\xc3\x9b\x1b\xbem\xd2\x08x\x88p\x12\x89j\x97\xf5\xae\xbe\x03>i\xdd<\x18R\xe3\x08\xad~\xf0\x01\xb2KC'
        b"\x1e\x05\xc8\x00\x84\xb7\xe7l\x91\xa1Q\xf6R\xb2g'\xe3Y\xeal_\xf0W\xa7\xb3\xc8\xa4;\xb1%\xed\x84\x08\xc9P&]x\xb2\xb1,\x18\xc5\xc99\x97r\x8e\x82\x94\x15X&\x1b\xd8\r\x07\x8c\x9a[\xe4v+\xc5"
        b'\x0e\xdd\xb62R\xe4+\x85\xac\xef\xc5\xdd\xb6=b\x95r\xbc\xe2\xf6\x93q-b.D\x04\x19\xe1\xa3\\\'ZZ\xe2\x02\xe3\xa9@\xe1`*\xeb\xfc\xab\x0e\x15D\x9dU\xbb\n\xd6\x9f\x95\xca\xd8\\^\xe1"\x83\xa1;'
        b'\xad\xdb\xa4\x83\x06\x8dl\x80\x1a\xa7\xcf\xefV\xd2\xc0/\x10\x18\xca\x1d:\xa5J96<6\xe1\x9bIX\xf4\xd40,\xd0\xde\x12l\xb2\xc0\xe1\x06\x9eS\xcb\n\xce\x00\xd2\xf8\xeb\x82\xceH\xa7;\xc5\x18\x1f\xc0\xe3\x02\x90'
        b'\xeb\xb7\x12V.[A\xc4\xf4\x94\t\xb7\x12a4_{$!\xb0\t\xa3\xd2KHr\x95\x8c=eL\xf9KG\x83W\xc9]\x97\xfd\xab\x13\x04<\x9e8\x87;\x98<\xb7\xa40\x05:\xe8W\xda\x9d\xfea\xd2\x04u'
        b'\x04\xf7\xa9\x00\xc3\xb3\x18^02\x91\xd9\xd8@\xce\x0e~\x1e{\xa0Fs_mr\xc7\x19\xdb1s\xbd\xae\xa4\x90\xd7\'\x14LN_\x1d\xf8h\x85D\xbd{U\x92O\xcfpZ\x9d\xea\x8c\xe4\x14"MDg\x03L'
        b'\xa2\xdfj\xfbI\x07\xc8\xe4\x08\x86b\xd4\xb6|\x9e\xf4\x0bY6ZO]\xba\n \x8a\x04\xe7\xac\x1a\x17O\xfe\xf2\xe6\xd0\x06\xf1\xe1\xd8\xf1\xa3\x0fB\xbc\xe6\xd6\xdeJU?Yu\xc3Vj\xf5*\x1c\x99\xba\xc4\xb3l'
        b' \x01#zbE!\xbbK\x17\x82\xdc$\xc4\xf0\xber\xcf\xf4\xad\xb2\xd8\x9bMf;\xb9\x9a\xdd\x97n\x87\xc6\x0b\xbe\xd4\xf6\x86\xf8\x9b\xe8 \xa7u6V]\xc1d\xab\xc9vZ\xa0m\xf9t\x1fs\x95\xfc\xf4r$'
        b'\x008\xb3\xc2E:\xbe"\x13<=\x9ch\xc2\x92\x11\xdc\x16g E\x8eh6K\xcdR\xdf\x01[dj\xd8B\xa9\xce\x9c\xf06\xc5\xa9K\xdd}\x9c+\rS\x82/\xf9\x8d\xb3\xea8\xa1\xab\x0f\x10RT\xd2\x92\''
        b'<\xe9\xcb\x94\x01\xa64B\xc2W\xab`\xcef\xed\xfeT\xbaY\x9fpS\xba\xe0\x92y\xd3a\xc9\xbf\x0ei\xe4eU\x90\x99\xa5\x1e\xbd\xd2\xa7\x14>\xca|\xd3\xf4\xa7l\x82\x17*\xcf\xaf\xe6{\xce\xa1\x9a\xad\x18\x05\x89'
        b'\x96\xec_\x94Gu\xa1i\x97\xd9vO\x0f[E\x01\xfe\xa5\x9bl\xec\x1a\x82\x05\x9d\x88\xb4\xdb\x93\x11e\x9b\xc9\xcf\xa3\xe4\xc7\x12\x85\xd4y\x155\x9b!=\xf0\x94\x03p\xc4\xbe\xde^\xa51\xdb\x1d\xf1\xfa\xe8>\x911'
        b"Z\xb3\xf3\x17\x97\x07-0%\xa5\x89:\xe3\x16\x00\xc4\xa0L\xba6Z\xf2\xad\xdb\xb9gO\x8a\xf1\x17.kC'\xc5a\xefP\x1dSj\xad\xe8\xbdj\xea\xaa\x904''m@1\xa5\xdaUg\r\x07\xe1\x12\x18b"
        b'[\xfc\xd8\x7f(\n^*\x96\xd0H\x1a\xaa\x84\x85Qj\xda\xd6\xdc \xa7\td\xfe\x80\xae\x17::\xec+T-\xa9\x8c4m\xb8\x07\xe6tW\xb8\x84=\xa3\t9\xa2*\x16L\xcc\x81\x87\xb9\xa2\xf7,\x8a\xe6\xc2\xc6'
        b'\x9b\xac\x1aO\x97~\x1f:\x0b\xfb\xae\xaa\x9a\xdb\xe5\x80\xa4<\xc2\xa5R\xd7d\x85r\xab\x0e\x94m\xe5X\xac\xf1\x17\x19qWo\xc6\xa7\xb9\x9e\r\xba\x93\x90T\x12\xe1\xa3\x10\xf7\x91\x83\xd6\xd5\xd3=\xc9\x8eT\x9f\x94\x96'
        b'\x88V\x04\x87M\x93{Ws\xe8\x19\xfd\xc7\xa9I`tWwD\x10\x15\x1b8\xcf\xf3\x86\x82\xc4\x94\n\x94a\xc7\x8b\x03\xc4\x18*\x11\xa2L)\xad\xd8=\x14[\xa0\xd1wK\x8cC\xb2\x05\x8e!\xbe7d\x92\xf1\xdc'
        b'\xdb#\xb6}z\xbf\xfa@)\xc0t\x84k\xafQ\xd1\xa8\x17t\xc7\xa7\x81\x87\xae\xec\xf9%zv\x1d\xeb\x98\xb2;`\xbd\xf0\xf7O\x99B\xd9\x18\x9a\x99byg\xa7\xe3\xb8\xdf\xa1\xa9\x0b\x13\xbe\xf7\xddB\xad\xedG|'
        b"c\xc4\xcd\xd4\x0cX\xad\x19\xf1\xe0E\xaa\xb5@k\x18\xd3\xe66R\x9c\xdd\xcd\x8f\x85\xa1;['\x83\xb3I\t\x0e\x9ek\x92ZV>\x1d+U\xc5\x81\x96Z\xff\x91\xd9\x19s}s\x14\xe2aw\x16\x89\xb9\xcb\xaf["
        b'\xbd\'\x93n\xe9/\xfb\xb1\xf9i\xac\xe4\xfa\xdep{\x1f\x96\xe8nC g&\xebU\xee\x08\x81Aw\x04\x933|\x81\'\x9d\x94\\\\&\x87\x00\xea"\xea\xf0\x90\x97\x15\x87\x06\x9e\xa4R{\x11e\xf5[\xea\xb9\xfb'
        b'\\\x9e\xf8+IP\xa8\xd5\xf7|=\x8cN\x98X\x17\xcb6\x88\xa7\xc6\xff"\x7f\x1b=\xa1\xda\xc1L\xc4.\xf3m\xff\xca\xdb\x1f\xb9\x9b\xb7\xe9\x18\x11\x90\x8dr\xb7I\xfaV\x97L\x98\xb1\xab\xdbK\x17_2p\xa0\xfe'
        b'\x1eacpje\x89\x807\x1eD\xbdY4\x8e\x02\xbc1L\xce\xa8G\x10\xda\xb1\xbf \x07a\xf8\xacj\xf9\xdbW\xca\xadV\xa1X\n \x86V\xb0\x16G\x17(\x9b\nJ\xe2\xe9]+\xa8\xd3;\xb4\xb5\x8c\x10\x9c'
        b'\xf0\xdd\xee8\xa8\xd9\x8b\x86\xc4_h\xcb\x1f\xba\xe8\t:5{b\xc6\x98\xfeA\x1a:I<\x9f\xfa\xb1\x93\xb2EqR\x9b\xbf\x1e\xa3V)\xc8\x14c\xcd^n\x93\xdc\x87\x8a\xbc\xda\x14S\xda?3\xbd\xa4\x93\xfe\xd0'
        b'\xbbE\x88FnR\x7f\xaf\x14\xff\x84\xe9[\xf8\xc4[\n\x7fi+\x11\x87\xf8\x16-\xbbg\xe7\xa3\xb3\x0cT\x1d\t\xbd%4\x03\xd1)\xf3A?H\xf1\xaa\xba\xcf\x00\xf7(\x84\xcf,\x8f\xa6\xcf\x96\x86ZT\x04\x9b\xb8'
        b"\x05p\xc4\xfa\xdd2\\\xbf\xbc\x96\x85\\\x12G'\x1ab\x05\xd4\x19k9(c\x03F\x0cQ\xfd\xedL\xc4\x03rjI\xe8\xa6#!>\x8fn\x9e\xb8\xb7\xff\xdb\xa6\xc3\x9da\xfcb'7c\x93*\x8c\x0bi\xeeb"
        b'{\x99o\xac\xf0\xf6\xa6F_\xcb\x15\xa5l-\xe9-\xa5;c\xc2\xee\xba\x1f\x08r`\xe49H\xcd\x84\x97\x1b\xf2\xdd\x93\x19\xa2D:\xdf\xe8u8\xc4\x8f\x16.\xe6\xbfY\x8a\xd3\xad\x8f\xf7\xcd\xe4\x11\xf3\x05\xe8\x80\xa8'
        b'\xa4\xc0\xcd"\xceP\xf0r)r0\x14\x86\x17\x12\xd0\xf6\xa1h.\x04\xe0\x10\xd1Q\xba W\x99^\xd5\xd4\xf1\\\xb9\r\x11\x83\x92\xc2r\x82\xc9\xb5\x0fK\xa1QhLNJ<\xd6z@C#S|\xf8\xaah\xac'
        b'\n\x7f\xfa\xf0\xd19\x8cu\xc0M\x0c\x9d"\xe17\xd5;I\x9d\x12D\x9b\x92\xca\x81\x84\xea\xc3c\xfb1\x87\xbb\xbc\xc0;4\xa3\xa2r\xfd\x00<r4\xedX\xf2,\xc8\x97\xf3U\xdd\x8c\xb2\x93\xc92F?gd2'
        b'\x96x\xaa\xc9\xd4\t\x8c\xf9\x0c\xda\x93\xc53\xd6q\xf1\x88\xd1\xb0\xacjx\xc3;\xcc\xe0u\xdc\x80L5\x92\xfc\xaeW\xf8V7\xe5\xbd\xcb\x19E`\xbfQ\x9b\x84Y\x0b\x9a\xae\x08\xa2ClA`\x1a\rDJ\xc5\xf5'
        b'\x9fz\xb2\x9ae\x12\x99\xc6\x0b\xd7\x83\xfd\xb3_\x8f_\x1e0\xc2\x0f\xfaj\xcd\x93\x08\x0e8\xb5\xe2\xcd\xdcr\xca\x01\xd1#\xfb\x95(+\x8a\x1er\x86:\x01\xb5\xd3\xb7\rI\xdfN\xdeb \x0f\x18\x81\xa8e\xd3\xac0'
        b'\x89\xf2\x93!\x15\x1f\x9d\xbfFX\xc1\n@\xd4"\xb82}\xa5q@`\x07KN(;CGzS\xa3[\x8b\xfc\xd0]\xa2HB\xad\xef\xc7\xdb\xe2\x1eq\x15\xae\x87Z\xf4\xc3\x89\xbb\x7f@w\x9bZ\xc1o^#'
        b'\xd1\xf3\xa9\x8b\xb3\xe0\xde\xf6b\xa4\x99\x14\xfd>\x0b\xc34\x9c3\x1d\x80)u\xedy\xf5g\xd6\xdf\xc7s%\x9al\xed\xad\xb2S<fJ\xc8\x811\xfd}\xbf\xbco\x94\xc1\x0bN\xa78\xa3i\x92\xa0\xc6\xfd\x04\xd8\x16'
        b'\xd4G~\x04\xa5\xa0@\x0c\xf6\x91\xc6vX}\x19A\xcf\x01\xcfU%\xd6\x16Roe.\x9c\xa5sB\xe3!\x88\xd7\xbb\xae\x804\x1c\x8f\xd4d8*\x9da\x13\xca\xb9K\xcd\x0e\xeap\xcf\x1eL_\xc9\r\xcb\xe9\xec'
        b'\x9e\x14\t\x86\xaf\xd6\\zL\x95\x87\xe2@M\xeb\t\x18N|/\x1d\xbc\xaa\xce\x92\xc4\xe7\xdf\xa4\x08\x9c\xfd\xfa-\xc7\x82\x8c\xdfAE\x90\xc9\xa1!\xef\rY\x0fm\xc8\x83\xfegd<`\xd7;\xb3\xbb\x0b8[\xbf'
        b'\x85\x8e\x8e\xb5>\xe6\xeeu\xc7\xedm\x14\xd2O>\xe5fI\xc6Bt\xc6\x85\x80\x9a4\x0e\xef]\xcf5\xb5;\xda\xda\x11\xf9\x99\xd5\x7f!8\xde\x7f\xf0\xe7\x9b[\x89\xec\xb4>\xe2ic&0\xe3~a\xb7r|g'
        b'\x11\x0f\xe5\x940\xcb>%\xb1*\x13f\xd33\xa9\xcf\xa7v\xd2\x819\xa6\x96\xd1&ac\xa2\x8bT\x01\xeeHl{\xdfK\x16X\xd6Z\x96\x14\xba\x08F\xaew\x98\t\xe2(\x90:\xac\xaa5\xd3\xb0\x9d>\xdf\xf7\xc1'
        b'\xef\xf5.\x8e\xb8+\xeb\xab\xc4i\x14\xde4#\x97\xe5\xab\xcda\xb2k\x833\xeb\x7f\xa3\x8b\xaa\xef\xfc `>\xbd\x83y\xe5\xa3\x1f\xdfzb\xd9\x9c\xcbv*H\x014\x1b\xeaT\xf4\xa5\xac,\xeb\xc5N\xee!\x19S'
        b'"\xa0\xfc/\x8aZ\xf3\x93\xa7\xd9\xfb6S@_\x0e\'g\t\x85>\xef\xd7\x0e\'\xadJ\xfa\xbb\xcc\xde^\xc1\xbb\xb2y\x07<\'v\xee\x87\xe1X2\xcf^b\x9d\x84x\xbbk\tY\xe0\xf2\xf5\xbe9M\x05\x08x'
        b"h$\xce\x925\x8a\x95:'\x9e3\xfd\x1bd\xd3\xb3\xd8\xf3%X=\x95y\x19\xf5\xe4s\xea\xd9\x04\xfbS\xe8D\xefE\xb6\xc0\x18\xfdUh\x11\x155,\x98\xcf\xf2fJ\x17O\xa8\xb4\xe3\x9a\xdf\xaf#\xc0p7\x13"
        b'\xbb d[4\xd4\x0f\x8d/4\xb6iV\xa3\xb1b%\x86\xf2\xf6\xae\xeec4c\xb0\xb2\x10J\xddT\x0c\xff\xa0\xb2\xb3\xab\xd0\xa2\xa0q\xe1\xe9<\xd3\xdb\xb2U\x04\x18\x84\xe9\xff\x1f,\x9b\xe0\xdc/f]HN\xca'
        b"d\xfdK\xa1p\xcc\xdc\xec\xe3F\x1d=\xee\xe0\xe4\x1d\xd0\xfe\xdb\xe6\xeb0\xc7\xf0\xf1\xb8\xbcH\x05\\\xd3\xa6\xac\tZ\x16d=\xe1-\x83\xd1\xe5\xe5\x15Lj\xd4z\xfc}\xda\x01,\x0c\xd6\\\xe1\x0b'\xe8Q \xbc"
        b'\x1a\xb0:\xa0\xccO\x0f\x17\x1dd\x0eY\x1f\xea\x81\x15S=\xcc\x10\x11\x94\x81\xc5\xab\x1ah5\x0e\tM\xd9<\x16\xd3D3\x9e\xd4\xec\xdc\xd1\x13r}\xe97|\xc5\xe8\x10\xa7\xf5\xed\x91\x07vP/\xf6\xc2^\x97\x86'
        b'\xdc\xca\xd4<\xc2\xee\x93DA\x80\x95B=\x91\xe9\xa2\x1e\xb6\xcbI\xbd\x90\xc0\xa1\xb5L%\n{>AW\x84\\\xc7\xcd\x93\tT\x11\x9c\x03\x88\xb0\xc8\xa3\xf1\x07\xfem\x88\xf6\xfe\xce\x7fh\xa5\x93\xc9RDn\xaa\x97'
        b"SSG\xb7\x06\xb3\x02},\xaf\x15=\xf5\x13'2\xed\x8b\xee\x89\xdb\x1c\x9en\xbc=\xe6\xf7\xc1\xf6o\xf2\t\xcf\xb2\xb4;\xb5u2y\xbd_\x86\x19g]7\rUI\x1eo\xf0oiA\xa7dp/\xbeD\xf7"
        b'\xbffM\xef\x8d\x03\x95\xeao\x84MN\x17\x04.\x9c\xda\xa8\xf2\xa9\xc8K\x12\xdfT;\xbe\xfb\xa2n4\x97l\xb50\x0b\xe0!\xa4\x1c\xc8\x87\xe0\x98\xf8@_6^V\x9d\xf7\xa8o\x05\xd0#\x95>\x84\x07\xec\xbd\x87'
        b'\x8b\xa2\xe6\xb4\xda^\xd1m\x9ece\x19\xca1L\xab\xd5C8|\x13N6\x88\xfd\xbf.io\x13%7\xcd\xae\xa3\xe6\xa3\x86J\x82k[\x8f%\xbe\xaf6 \xdc\xef\xa2\xf7\xf7\xc0\x9d\xe7>^\x8d\xe9\xb5\x0e\x9ez'
        b"\xb9\x8e8s\xd1\xa4fk\xde\x05\x92@!\xee\x9d\xe9\x11\x18~J\xdd=\x18\x0c:\x1c\xbd\x98\x1d8(\xa6\x1a\xe8,/\x91{\x8a\x8aY$\x01\xa1\xba<\x06b\x90\xaa\x07\xc6\xf1\xeb\xdc\x87\xeb\x1a\xaf\xb7'\x8a\xab%"
        b'\xe0$\xd6\xc8\x9f\x0e\x9d\x0c\xe8\xde\xa8\x1e\x94\x1a\x84\x19)\x9d7\xc4\xedu\x05\x9c\x9bFKd3\xa6Di\x12\xae\x14\xd9\xf2dR,\xc0\xb6\xdc\xdc<\x19\x9ci\xf1\xe6y\x1a\xd5\xba\xd5\xb9\x0bz-\xd83\xfe \xfe'
        b'G\xb0*\xbf\xa0\x0e\xba\x88f\xd6\xec\xa0\xa7\xa5\xd2dY*\xd0I\x9a\xda\xf8O\xe3\xdbK\x87\xa0\xd3#\xaf\xd3\x9a\xfb$\xed\xef\x18\x1d#\xf7 "\xc3x\x1cC\xc1G\xb5\x0f\xa9\xb0\xaa\xa9_\xc3\xe3\x809R\x13\xd7'
        b'\xb4~;\xf1\tT[\xaa\xcc\x10u\xa3\xe4WUm\x8d=\x12\xcb\x98\x83\x18|L~\xd0\\\x1e\x86\'p\xb4"\xef\xacE\xa8t\xd2\x9e\x9b\x17\xc3\xe0\x04\xdb\xb5\xe8\xa1\x03]\xbe\xc7Mx5\x85\xca\x1a\x84b\xa8\xdb'
        b'\xa6)\x81?\xd9\x8c\x8f\xc1-\xd32\xc5\xed\x1f3\xd1\xc0\x8d\xd7;=\r\xdc\x14\xe9\x08\x0c=]\xdcP-\x9f\xb4\x11\xb7\xdcB\x11l\xf32\xe4\xc5\xadlcr\xfeh\x98m)\x9d\x10.J\x17\x82)\xb2\x1fs6'
        b'Z\xfe*\xcb\xbb]\x16\xdd\xfe\x17\x9b/\x03\xed+v\x7f\xa0\x064\xea\xfc\x07\x8e\r\x0c\xbfA8\x009_\xf4A\xb7\xbf\xae\x9d@C-\xbf\xc8\x11\xda\x80L,\xa9\x8e]\x1e\xb3\xdaYH:R\x96:\x86\x97,Y'
        b'Y\xdf\xb5\x9d\x89\x7fQ\xbc\x1c\xdf4a\x18v\x1b\x132:\x01!\x0e\xb8\xe5\x0e\xdaw\xfe\x8e\x95\x15Puk,!ul\x80\\\xdb\xed\xdb\xd5.\xbc\x87\xd3C\x10\x95\r\x95\x00\xc3\xb1\x11\xc8\xc1\xee\xcd\xc5\xdbf\xf0'
        b'{\xd4\xba\xa8\xdchk9e\x919\x97\x04\xc2\x8dE\xbc\x12\xf8\xe0\x94\xd7\x16\x07\xed<\\\xd8\xc3\xaa\x86\xbb/\x0c\xefTb\x1d;O\xe6\xe5\xe5\xb62\x18\xd8\xc9\xe1\xb0\x1f\x83Nf\xa2\xdb\xfc\x83\x93@\xb3*i}'
        b'&\xef\xfcm\xb2\\\x8dyO\xd2\xcf\x1e;j\x0c/\xd9\n\xd2\x80nlu\xe4\xf6\x9dw`W\x00\xc2\x02[!\x9f\xfb\x9eb8\xd8\x11|\xa9\xcb\x92\x8c\xd8 N\x1ejJ\xa9\xcf\xf0\xe3\xbd{\xae\xf6\x9490M'
        b'\xd2\x86>%}D\x90,8Y\xf7\x12\xeb\x0e\x914]2sO\x85\xbcs>\x16\xdd\x16\xe7\'W\x9c\xbe\xe90\x12"&\x13!@#WR<\xdc\x0c\xad!io\x14\x7fd\xf0\xe3\n\xd1\x93tg\xd7X=\xb0'
        b'Ae\x97I\xce\xc2\n\x86-\x032\xb6/\x17\xf2\xf4 \x1fK\xc0\xf5d\x94\x0cV+\xba\xe6\xbc2o\x9a\xa4\x14;\xa4f"Q\xde\xa8\xc4\xf9\xb4\xc13!-\x89\xe7_0\xd0\x83b\xe7\x04\x93]f\x81\xf5)\x9d'
        b'-3\xbc\xb2\xc5\x7f\xaf\xccH\x13\xec\xb8\x89\r\xf7J\xd4UC!\xaa\xb1\x91\xac\x94\x85\xad\xc4\xc6h\x8b\x07\x1e]\xa7"\xc6?L(\x15.\xe3\r>W\xaf8>\xc3\xf8\xc5$\xb8\xa1\xb6\xcb\x8a\x94zid.c'
        b'\xe7\xd3\x17_\xb4\x97\xfb78\x08;$\x01\x19\xc3#\xaa(\xea\xb6\xe9\xcau`\x90\x12C@\xad\x89\xeeT\x9a\x83\xa8\xd0\x1e2\xc1\x0f\x00o\xb5\xe93\xc8\t\xf4\xb2\xff0!\x90\x121\xefn\xcep\x15`#g]'
        b'\xc2\xe8,\xa4\xce\x17\xd9c\x01W\x0b9\xbf\x88:\xeb\x00\xa0xw\xfd\x94\xf0}\x12\x8a\r\xb92\x93\x15\xbb\xc4\xd2\x9aHC\xeaC\xb7\x9d\x04\xf5Zy\xe4\x18\xf4\xca\xe9\x16\x0fj\xb8\xc9_\x0c3\\T\xd2\x91\x9d\xcf'
        b'\x88\xc5\xabJ\x8f\x1d\xa0C.\x9d\xa7\x89\xc7\xf8\xca\x10\xedZ\xd1\xe6\xf0\xfd\xcc\xc0\xfd\x97O~\xbc.\x03\x8d8f\x0e\xfa\xfaD\xbc\x89\xbd0\xb8\x82\xc4\xb57\xd4\xad\t o\x8bT\x18\x88\xe3\xef&\x86\xd2\x9c,3'
        b'q^\xd2lhs_\xa8\x1d\xa7\x95\xc1\xa0\xc2ZyJ]\tI\xa9\x82\xca\xdcV\xbc\x0c\x90p\xfe\x9a\xde\xc7\x7f\xe8x\xbag\x9c\xde\x93\xdf|\xcd\x0c\xb6$\xa99\x13\xc0\xfe\xfb"\xd2\xe1\xd2\xacR>\x9b\x86\xe6\xda'
        b'9\xbb\xf0\x9d\xa4\xf7cSf\xff\x9d*\x90\xa3\xab\x034 (\x08Q\xd2?\x0f&\xba\xf7#E\xd8(\x12t4(\x8a;h1-ya?\xc2\x9f\xbc\xab\xdcV\xa0\xa3\xcb\x7fn\xf7\xb5e=W\x90?H\xa3<'
        b"EG'\xe4a\xad1\x91\x06\xc2\xcc2\x05t\x7f\xf1k\xf0B@\x1aN\xef\xcd`\xd9\xa6\xc9z\xb1B\xa86:\xb4\xff#%\xf8G\xcd_\xd8\xdeQfWa9\x0c\xa4!\x9c\x9f\xe6)\xa823\xd6\x14'o5"
        b'\x19 \xd2-\xd1\xb2\xc5u\x98\xd1h\xef\xae>[\xc8\x8bXaad:\x93j\xe3(\xc8\x98+\xa6/\xb5\t_j\xf1CD\xfb\xd2\xc8\xc7}\x8c\x9c\x96}\xd4I\xf8\xb9\x8a\x8d\xd6k\xb6\xb3a\x9c\xd9h<\xc1e'
        b'\xeb{\xcaI\x9d\xb9\xfb\xd5}&<\x01\xa1\x9fH\xfa\xba\x9dM\x15\xf1\xef\x0b_\x02U\xfeM\xe6\x90=\xe5\xa0\xdf\xdaK&\xec\x97\xd4\xd3\xb7\x89\x94\x05\xeb\xca\xd9\xc7\x13k\x1b\xf2W,T\x8e\xcf\xb5\x1a.\xcf\xed`'
        b'\x13=\xa6*H\x1f]>\x86oh\x07U\x8c)\x82\x9d\xac#%\xd3\x87\xd3r\xf6xP6E\x8b\x0fb{\x16\xad\x14+m\x01|\xaaiq#\xc8c\x9b\x18s\x8b\x17\xbfm}K\x89\xd4\xa7\xdcW\x1c\x06\x0bu'
        b'\xfe\x02c\x97\xac\x90\xce\xe94\xf2%\xc2O\xb0\xdf!\n\x81\x0b/E-\x7f\\\xd1\xc9[\xe9KaI\x8drj\xf7\xbf\xfc\x95\x81\xb5\xcb\x8esH/\xb9\xed\xac\xe2,\xd9\x0cf\xfc\xb2\x00"\xfc\x8f\xf5\x8e\xfeG8'
        b'#\xcb\x8b\xe0\xe7\x9fok\x1bM\x8d\xb7\xb6\x96\xbd\x88\x10\x7f\xed9g9\xd4\x02\xe9\xf6\x16B\x95\xe2Hg\xd9\xde\xc6\xf9\xb1=\xf8\xf6\xd7;\x9f\xbb\xae\x01Cb:\xb8N"\xdd#\x1b!\xa3&\x19$\xde\x15\xda\xb5'
        b':\x9d\x13\xaa\xc4\x89b~d\xbd\xf2?\xbe`\x82\xcfQU\x10\x0e\x92\xf7\xa1\xbf\x80W\x1c;\x85\xff\xea\xf5\x87\x9d\x82\x97{\xe8\xbf\xf4\n\xe3\xf4\x92\xec\xd3\xa0l\xfb\x07]K\x80\xd9}\xee\xb7\xb8\xdd\x1d\xe5\xc0\xbdY'
        b"'\xcd\xff>BQ\xca\xdd\x04\xbfS\x99\xa9$\xf1\xb3B\xad\x97\x15_'l\xc8\x8d\x0e\xea\xfbS3\xc4\xb4\x15\x89\xb9\xf0\xcf\xb3S\xf9\xbb\xbd\x8f\xb0\x88\xa6F(\x1a\xad\x8d\xa5\x9e3\x10w\xe3\xda\xe5\xbc\xed*A\x05"
        b'\xe9d\x0bQ\xd3\xd9\x03\xf52\x91~[\xaa\x19\x06\xec\x1f|\xf6\x10\xb0\xb9J\x17WL{\xbd\xb7g\x99\x9c\xe7\xa3\xb3\xe9,\x83o\xffF\xcf\x04!LK\xbc\xcc\x18\xb8\x1b<,\xf4\xda\xe2u^\xe1\x9b\xfcE^%'
        b"\xfe\x8a[\x87\xd4\x06\xc1>\xd4ppKzEgC\x93\xf3I\x06Y>^X>'\x13\x0b\xea\xee\x0bc\xa2\xc1~\xe0\xbe$\x0e|t\x9c\x9b6\xa6\x02u)\xda|W\xc3I<\xc1\xd9\xbc\xfc\xea\xe5\xbe\x17\x99\xce"
        b'%\x8e\xdb_\x1d\xfeH\x96\xbbH\xde\xe6\xe4dz\xc4\xfb8\xb1\x16\xd5Q*"\n0J\xb8\x88SS\x00?\x14\x9c\xb3:fG\xa2\',\x1c\x05T\xff\xb43\xd9\xbb\xc2\xe3\xaeh\tW\xb9C\xf2\xf8\xba[\x05\xde'
        b'\x06\x08S\xe7\x9fT_\t\x01E\xc1\x11\xe4\x96\x7f<g"&0\xe9\x1e\x83\xef\xbc\xefv\xf3\xba\x04\xa0\xc3p"o\x7f\xa4R\xa7>\xaej\x87y*\xfa4\xb9\xe1\xa6q\xf0\xe1\x86\x90\xb5\xc8\xe5\x04\x8b\xc7n\x1f\xe6'
        b'\xae\xa3X\xbf\xd0\xbcf.:HW\x06Ybr\xccS\xce\xbei\xc9\\\xbaezEP#\xeb\xae\xcf\x11\xd8\xa1h\xfcwb\xe4\xd1\xc2\x91\x92\xfaj<\xeemB\x00|\xcc\xa2\x97j\xb1\xf8@:\x903\xda.\x9c'
        b'\xca"\x9a%\xe7\xafV\xf9\xb2\xe9;v\x14\x85\x933o-\x9e\x8a\x9e\xa8\t\xe3b\xf9B\xcb7F\x02O\xc1\xe6j\xcf\xdf\xed\xab\xff\xddqK\xd2\xd3\xf67\xf7U\xf8a\xf5U\xa1\x8b\xaf\xec\xb2i\x88\xbe\xd1\xee\xa1'
        b"\xa3\xc6\x95\xca\xf9\x1d\x8d\x18qY\x18Cm\xe8U\xedJ\x90\xbc\xf3\x7f\xf2;\x0c; \xfb)\xd3\xfb\x12\xe2\xb7\xee\xd2\x05\xda\x90\xe6\x11\xeb\xf1\xd2\xb7\x0e\x13\x92\xef\xeb'\xb2,\xca8mx\x88~\xdbMp\xe1\x86X"
        b'O\xa3\x00;\xe3wOZ\xf9|\xb0\x07[\xfcG\xddH\xdbGo%\xe4\xcb\xef\x7fx!&\xbd\xad\xde;xA\xda\xe4\xde\x8aB|U(\xc6\x0eL\xfb\xba\xa0\x05\x08\xc5[\x18\xf4\x91\xe5\xfbcr\x96\x87\x1b\xbe\xb0'
        b'\xf7=Eu\x06\x88\xc9\xe6\x18\xd2`\xe7\t\x17"\xa7\x15\xd3\xea:hdh\xed*\xae\xf7\x0e\xca\xe5L\x98p\xa5\x9a<\xe2}x\xbdfe7`=7\x93\xed\x96\xb0\xed\x94\xd87\x11N\x115%g\x14]\xd6\x8d'
        b'\x88\x08\xe8\xa1~\xf6\xc45S\xfb\x1df\xddU\xf5\x05 \x1b\xdf\x05ie\x12o\xb9\x93?}\xc1\x13\xae\x13\xf6`#\xddA|\xfby.\xc8\xa79\x8d\xa6\x17\xda\x15v\x94|\xbd\x1f\r\xb7\x18[\x0cp\xf2\xeb\xa1-'
        b']A\x1dtA\\0 \xd7\x97s\x83\x1f\xf5\xb9F\xa9\xc9S\xd3}\x8e\x1cg\xe4\xb5\xac\xcf\x99\xea1C\xcd\x0c\x9f\xdcO2\x7f\xce\x17\xa7\x0f.\xac\xa68\x1f\xe8\x11\xa1X]\x99\x19/\xab7\xd2\x16$W\xbb\xe5'
        b"\xb6-\xc2\x16\x0c\xe8\x1a\x07Wqz\x1b\x81>\x02@RL.\xe2\xf5y\xb1\x81\x02\x1f\xb2\x88\x99R'\xeb\rz\x9c\x1b\xb2\xf9~&\xe18uq<\xe3f\xf1\x02\xc1b\x89\xb83Ov\xe7\xa0\x975\xaeL\x8b\xff"
        b'\xd3$\x02\x8a2p\xc0\xbf,^!\x0cC\x9eB\x89\x94\x92\xaa\x99\xca+<\x9e\xd7\xc3~\xb1&\xbcz\x9a\x9b\x95$L\x04\n\xa1u\xae\x83\x1fe\xf8A\xb1\xe5=\xefHeX\xbd\xbb\x92\xbajh\x0e/L\xc6v'
        b'{8j\x8f\xe5\x99\xed\xf5\x18\xd1m\xd2\xd6_\xe2f\xebQ\x11I>#\x84U\xd8?K9\xa7\xf3G,\x18_`G\x8e\xa0\x81\xc44\x8e\x7fu\xd6s\xac\xb2\x0c/\rt_\x82\x7f\x8e-\xad\x9dX\xac\xa6\xb51'
        b'Y\x15vo\xd1@\x9c\xdeg\xeb)\xfb\x1c\x8c\\OL\x13\xd4 \xc3\x1aF3\x95U\xe8\xecD\x0c2"\xc1\x16\x17rrer\x9d+E,]\x81\xbc^ip\xd4y\x12\xbe\x18\x13K\x97\xa57T\xa6Y\x17i'
        b'A\xac\xe9\x1f\x18\xf3bG\xba\xc6*c\xc4&\xcdE\xf2\rz\x08g\xbcY\x1b"\x84;\xa9\xb1\x193\xd1es\x9c\xb1\x07<\x88\x1a"\xc1\xec-Q\xe4erq\xa8R\x01\xb2\xd9\x85\x90\xfe+\x9epy\xd5W\x18'
        b'\xc2\\"\x1b\xbdC.\xd1\x0c\xff\x8b\xbd\xf2\x07\xf3\x88(\xf7\x16\xec\x0b\xack?zV\xd1\x1bo\xae\xb4\xee*<h\xff\x13\x18.\x92%\xb9}\x96\xa2\xc7\xc63\xd7\x17Ri\xc9\x9b\xd8B\xd3\xe5.\x81Z@)\t'
        b'{\xe9\xaa\x90\xe5i\x86\xc7\x18\xc2/\xaaV4\x1a\xc5vy\xe7\xe3\x00\xc6\x80?\x80\xa1{\t@\x97dC\xd2w\xe5I\x88pa-\xbe\xff\x06\xff\xc7\xa0!G\xfcz\t\xda\x84o\x93e\xdb\xd4\x08;a\x0b\xb9\xf7'
        b'b\xc4\x0e\xef0\x8a\x91%\x0f#\xa5\x8b)?X4\xaa\xfd\xf97\xcd{\x05~\x7f\xa5\xe9\x08\xe9\x08\xea\xbf[\x07\x0c+\xcc\xcfC\x8c\xa6\x9fW\xfd\xe7\x88kDy\xe9:\xf0\xfb\x08.\xa7\xf5F\xe2\xfa8\xc0\xa4\x14'
        b'\xbc?\xb4S\r\r\xfbj\xe1\xfbe\x9b9d\x98\xaa\x8d\xda\x15\xc0\x18\x97\xca6\x8f\xe9\x141=p\x85\xb8"\x880\xdb\xe3\xc8eY:\xbbKk\x99^\xfb\xd5K\x88\xa8\xb8\xa9\x14\xbb\xb9\xbf>\xb4\xf7\xfds\xb1n'
        b'\xef\x01}\xc8\x03o5S\x9b\xe9\r\xb0\x84t\xdb\xa6\xac\xa8Px\xd6x`t^\x19\xfb\n.\xb5\xfam\xd9QM`\xea \x83\x171~\x0b\xa9\xf1=\xd1\x1fu*B\xcf\xa8\xf3\x87i\x1a\x13\x0bt\xfd\xafM;'
        b'\x86\x8c\x86\xa2w\x80m\xa0X\xaf\xac\x1e\xc8\xc6\xa1u\xfc}\xa0\x00*\xf4.\xa7\x84/<\xcb\xe7p\xc2"k\xd7\xf0\xffC\x97\xf0\t\r\xaf<\x9cB\xca\x98\x16\xf1$-I\xe6,\xecz\x91\xef\x1f\xe4\x12_b\xed'
        b'\xb8|\xfd.\xd0\x86\x93\xe3O\xf8)\xd5\x01m\xb5\xf6\xb3k\xf0vgA\x82e\xad\xc9F\x062@\xffA\x8e\xeb\x9e\xaa\x94\xa7\x19\t\x01T\xdf\xceZ\x8c\xf4\x92\x1e\xdeP\x8b \xb0\x06\xddP\xc7\x98\x10\x19}\xa7\xc4'
        b'\x957\xed\x03\xc4T\xc1\x8e\xech\xf3\x82\xd6\xe5f3g\x839\xed+\x93\x93_ap\x97\x90\xf4F\x7fZ!\xd3\xea\x93`\xd4\x8a\xf2P\x942o6Jm\x80@\xb4\x95\x9aKH\x82\x06@\xe0\x87\x16A\x7f=\x0f'
        b'~\x01V\x8e\x18r*Z\\\x07\xdb\xf5\xbe\x10;3d\\\xdc\xadbF\x11q\\\xab\x8a%\xd0\x15\xb8T\x026\x80AU\xf6\x15\x98\xf3\x82\x9a/6\xbb\xfcy4\x0bK/1&\xe2\xd4C\t\x05\xc2\xa7{\xf6\x94'
        b"\xd6\\\xcb\xd0\x92\xae\x93\xe2\xaf\xa3\xe8\x13\xa9h3H\x01\x93\x19\x06\xb5\xea\xe8\x86\xfbO\xf0V$\xea\xb5\xe9\xfb\xed\xfd\xc5\x1es\x91\xc6\xb7\x80\xea\xa0\x9a\xf0\xd0\xfb\xd3\xd5\x8b\xde'\x10\xda\xdf2\xd8\xea\x19\xd7\x9eJ\xe7"
        b'\x10\x00i#@\x9e?\xdf\xd9\xd5\x0cR\rz\xd0M\x19\xb5\xa2M\xedq\xd0\x08\xd7}o\xd1\x08\xa2\xabW\xf0\xe1\x7fZ\xff\x16\x1er_p\xa1\xdb6\xdf0\xa1\xb7^\x1d\xa6];\xf7\xfc-\xe8\x95\\/\x8c\xc9F'
        b'\x1d\x8b\xb7\x9b#)\x06"\xbf\xd0*\xdb\x91)\x19\xdbF\xf8\x19>\xd8\x8f\xa3\xf7J\xdd\x86\x97\x02\x8f\xd8\xb0\x8b6\x13O\xae\xd9\xf1\x01\xdb\x18\xea\xec\x10Q\xfe\r\x02\xf3\xd7\xfd\xfa#\x94R\xf6\xbf\xb9\xce\x86p\x9d\x17'
        b'Y\xbe+ \x0e\xdf\x13\xa0\xa7M\xc2\xe0\x01\xf3\x82\xec\x01\x079\xa8s\xe3\x84P\xb4(RS\x97\xa0#\x92d\xfaEC\xa0\x99\x81?\xfei\xbf\xf2\r \\\xb4\x0c\x173\xd7\x8f\xf0.\xc4\xec\xc5U\x990\xd7/$'
        b'\xec-\xfc\x8a\xe0\xff\xe9C\xce\xcd\x11#G\xbf9\x0f\x13T\xcf\xd7~C\x85Q\xca\x03\xd7!}\xc2\x0f\x0c\x92\x04\xb06\xca:\xd1Y\xeb\x83\xcf`\xefA\x15\xde\xe35J`/\x94\xe1E\xaf\x17\xb7\x1eg\x17\xfdl'
        b'\x98\x9c8\x91\xe9\xebQ|%\xd9\x1d6\xd0(F.\xe6D\xab2\n4\xc9y\xf2\x91\xc5\xc6_\x89\xc1\xd9\xedy\xbd\x01\xe2\xdeZ# \x14`\x868\xa4\xed\xb0g}\xa5#\x08\xa4\\\x14\t\x99=\xbe\xbe\x01\xbco'
        b":\xfdr\xf1\\\xed\x0e\xf2'\x08\xc3n\xdf\xa4/\xc4a\x9a\x9f~\xd4\xb0LA\xff0\xfe\x81\x8a\xed\xe5\x13\xa3\x1eQ\xdaKz\xa2P\x9do\xf9\xe6]e\x1bS\xe0\xd5\xe8x}\x89\xa8_rj\xa9\x03L\xb5I\x11"
        b'\x82LOyOTYc\xc6\x07\xfc\x96G8A,\x93\xf6\xc8\xba/\xe0\x93\xe7\xfe\x08\xed\x01oR\xa5\x1c\xbe\x1b\xa4\xd3DCB;u\xf7\xe6(}\x1e\xcf\xdd[&\x05\xa7\x90\xebw\xd3?\t3*l\xc0\xb3G'
        b'-\x8fY^\t\xb5M!K7\xbc\x8e\x0b\r:\xe2\xb8\xfb\xb6\xf8IZ\xd3fr\x87)\x13L\x86\x91?U\x8eE\xff=W\x1d\xc8*j\xcf%"\t\x91an\xd7\x9d\x06\x00\xe6\x82)\xd4\xb0\x19!\x02\xf1]\xb5'
        b"\x0e\x16^\\n\xd7\x8f\xd0\xa2}\xf4U_\x10Fr \x08n\xe6\xfaN\x91\xd9J`\xccF\x85\x8f\xefC\xc1\x938+\x0c\xba\x03\xd9\x05W1\xbb\xc3\xdeE'$\xca\xf3k\xaaX\x96\xbf\xb5\x1c~(\x12\xe7\xb0\xfa"
        b'\xa3\x7f\xaaChA\xb3\x15\x1e|vU?\xc6H\xd5h\xff\xc1\x13\x9d\x9e\x938\xdf(\xe9#DzdV\x1cGY\xfe;\xf4\x0b\x7f&\x1esu\'\xfc"\xf2\x03\xa1(\x87\x18\xbd\x84\x13\xa0\xd5\x81\xe7\xa4EZ\xa2'
        b'\x90\xdf\xdb\x9f\x7f\t\x8c\xcf\xcc\xd8\xbc\xc1\xf3F\x1f\x02q\x9ct\x89\xf9\x06 R:\x12OF)\x8f\x08\rT\x8f\xe5M\xc8\x88\xd0\xcf\xb5\xa1\xba\xa6\x1a\xf1\x15\xce\xe9\x16\x0e"\xe921\xa7{\x1b\rN \x82\xf8\xb7'
        b'\xbc\x01[{/\xa6?\x87HQ`\xf0\xc9~\x0c.5\x15\xb4Z\xa6.\x16\xaeR\x01\xe5Kn\x08\xb5\x96\xe5\xe2}\x8b\x9a\xba2\x9b\xd4\x90\x9d\xbc\x98\x15\xf9\xee\x18/ZN\xa2)e\xd3d\x1c\x82\xf8\x84G!o'
        b'2\x97/\x14\xb8\xa9\x0bt`i\xb4A(L\xcc\xae\xd8\r])#\xd4\xae<\xaf\x96\xe19"\x91^e\x06\xbd\xb5\xb5\x083\x04\xcb\xbaP\xd0\x15\x8c\x9e\xb5\xb7\xf9\xec/Uq\xbe~\x18\x11v\xc3\xf3;\x94\x15j'
        b'#\xd0\xcaz\xd0\x19V\xb5\x10q\xa2\x81X\xc3\xfa:V2\xc2\xa8\xa7\x9c\x9b\xe1*\t$\xaf\xb0RD\xc1-\x16\x98y\xe8\x95UMA\x0fmo"\xc2@s=pz\xb0\xdbj\xb1\xd0\x14\x88*_\x84\x05!\x86'
        b'\xef\x8b\xd7,cNB\x1b\x8a\xdf\x89\xc2\x97&\xb0\xe4\xdd\xaf\xdf\xcaO\x83\xffK\xecF\xa9\x95\xd5cg\xed\xce\x81\x87\xf9\x96A3\xeb\xab\xfe\x18I\x83\x0f\x18q\x95\x9b\xbe\x0eB\xbd5y\x18h\x94\xd04f-\x8e'
        b'\x0e*X\xd6\xe1\x00\xa4\x0f\xe5\x93\xcc\xf1\xd7\xd5I\x82\xd7\x8d\xa0\x0f\x01\xc8\x9c}\x16FcM\x8c{+`\x10\xa2D\t;\xa7\xab\xfe\x06Ys|\xc1\xfaS\x16\x0b:\x9bJA)6Rc\xdet\x96{q\x81~'
        b'P\x1c\xeew2\x9d\x03\x85C\x05\x86Eg\t\x10\xa6\x9b\t\x19\xb4*Xe?\xcb\xa5\xa4d\xc7\n$\\`\x03\x16B\xad\xf9\xd5\xba\xe1\x9bm\x9f\xdbJ\xf8i)LI\x1a]:0\xd2\xe1\xb3\x93]\xe4eI\x7f'
        b'\xfd~\xddK\xc1\x9b\x92\x1b\xa5\xb5V\xa6I\x89\x86>i6\xb0s\xc3\x1e\xb8\xca\x08M\xfc\xb7\x92\x9ekx\x8a\xb9\xc3$\x8fN>\xcfI\xa3\xa0\xe0g?z\x8c\xb4!\t\x10:\xefK\xd5&u\x84\xedod\xbe\\'
        b'\xb0D\xfex\x07\xf8`\x9f\xef\x99dG>\xce\x1a\x81\x07\x91\xc3\xf2\xf5\xf8#\xc2xs\xc3\xc8\x01_\x8d>l\xce\xa0J\x84N\x85\x1c{t\x9b1\xc0\x92OB\xf5`\xac\xc8\xcb\x05\xf3\x96G]\xcaK\xc4\x11f\x0b'
        b'\xef;\x11\xc6_\x00\xf8\xbb\xc6\xce\xb9\x1b\xc4\xb1\xae\x13\xb5\xb2\x02#\xa5\x8b_\xb9\\aH#\xb2\xa2\xf0\xbce\xd2\xe2\x8dYq\xd4\xb2\xb5\xca\xd2l\x1a\x89^\x99\xfc\xef\x149ZRa\xa8\x93@\x92G:\xb6!\xda'
        b'\xedK4\xd3\xef\xa6\x0c\xf4\x12\xbar\x91\xe6"3\x9dq\xbcD\x12\x01\xdcW\xe1\xf3bgIq9\x9b\xacB\xb1+N\xa5\x0fxA>g\x8e\xacgb:\xf8N!]Zg\xfc)28\xfe\xf0\xe6\xe9*s\x06'
        b'B\x90\xeb\x13\xb7|\x8d&\x06\xc8\xe0\x85"\xab\xae\x01\xf4.~"\x05\xe3\x84;\x17\xc3\x9b\x8c!\xbfH\xfa\xa6\r\xfc\x8c-\x04p\xfd\x97g<\x9b\xd3\xe9\xcf\x149\xe5\x94/T\xe2\xaa\x1fp\xff\xdcI\x9a{\xe6['
        b'\xb1\xde\xed\xd4\x05\xa0\xed\xbb\xfb9\xe2\x96\x9e+\xc2\x1ayIo\xa3\t\x9d\x8c\x8e\xd2\x8f\xdfr\xe8\xbcFz\xb0[\xf6\r\xfc\xe8\x1bf\xa8\x0fp\xb2\x8bqQ5\x00|\xe8\xa9\x92\xa9\x91[\xa6\xf2\x13\x97\x83o\xa4\xaf'
        b'\x0e\xe5\xbeV\\8\xcc0\x180\x96\xcc\x8a)\xaa\'\xba\x86\xc4\xbaGk\xbeza\xd4\xb6%\xea\x94\xe8\xca~)\xf9\xaf!\xa9\xe1\x87Xk\x02?\xc2\xdeb\xdeUa\xbc\xb2\xd6\x08\xd9"JZ\xdb\xb6\x02\x05\xc5%'
        b"\xac\xde\xfb\xa2\xcf\\Qx\xb5\x94I\x1d\xe2B\xd9\xf0\xe9\x02\xa5\xd5\xe9k\x1e\x17U\xdb6\x02o\xefR9\xc0\x03\xba\xe9\x94\xc75\xd7\x16\xfb\x04\x98\xec\x93Ev\xa1\xfe@S'\x81\x0c\xafGTp\xe7\x98\t\x1c8"
        b'\x89C\xd2b\xcd\xf1\xffR\xd8\x93\xf0\x82\x14o\x8f=M\xfe\x85\x7f\xc4\xa9\xbdM\xf2\x00.P?BF\xc9\xe52\xc3\xea\xea\x89a\x9d\xbf\xa6\xf2(.\x85\xa7o\xe4\xdf \xd4\xa3\xeeM\xb1\xa4\xda\xba\xff\xe8\x87U\xa6'
        b'?\xa3\xd2\xdc\x08\xca\xa7\x83y\xde<\xf0v\xa8\x0b\xb9\xfd\xbfaJ\xbf\x81\xf0:{K\xfd\xa2\xde\xfc\x1e\xbdG\xcb\xbce@33\xf1\xb4E\xc7\xeb\x9c\x83d\xfff\xab\xe7i\x05\x81\xc9\xb1\xdf\x08\xbeQ\xe5\x98\xf7)'
        b'\xa4\x7f\xb3\xa8Z\xb1\xee\x1cggI\x95\x10\xba\xce\xaa\xb3\xc2\xbc\xbc\xac\xfdg\x8fx\xa09\xb6\x08\x02w/\x83\xae\xc1\x19y\x9a\xed\x92\xban5\xbd\x03\x95\x93+\xf6\xff\xa8Q\xc6\xae\xc1\xfe2\xc7=\x9b\x8e\xcf\xbe\xe8'
        b'#P\r\xd9\xca1\x08\x05\xdf\xcd\xcc\x99\x97t\xaeA"\xb4\xa9\xf4\xd1mc_2\x17N\x848\xba8\xbd\r1\xd0\x14\x1b\xee-r\xdc\xfd\xe6W\xbaF\x90\x94{N\x1d\xf1\x057\xc7\x95V\xb7\x9a/b\x8a\x19i'
        b'c\x12\xf39\xc6}\x11\x0e\xee\xac\xf7\xfa\x86\xdd\xf7^( 8\x13\xf6\xe7\xb5\x90\xfcze\x94\x0b&\xc6\x1b\xdaq6z\xee$\xbc\xaaBKX\xe64\x96\x11\xfc|\xc5zr\xb7o\x10\xb8j\x84\xd2\xcd\xa7\xbe8\xe4'
        b'\x89F`(A\xf0\xabNn\x19\x14\x9f\xcf\xf5\x16tL7d\xfe\x98j90\x01\xd9\xb5\xd1\x1c1B\x84\xba&\rO5\xbe}KY\x92\xeaTN\xdc\xce\xfb\x92\x97fRW^\xeb\x81\x9f\x19\xd0\xe56<\xb5\xe5'
        b'\x92l\x7f\xd2-\xf0\xc7\xe7f5\xd4LVP\x9a\xf2fU\xf3\xad\xfe\xc4\x80\x19Q?ip\xe6\xfd(M\xcb\x88\xce\xacB$/)\xf5}N;\x9d\x9f\xc5\xb3\xc9g\xb9}\n\xadB\x96L\x05y$\xd3.\x94y'
        b'%\x81\x7f)b\x18\xdaw5\xa1\xb3\x8f+\xd5\x87\xaa\xf4v<\xac\x89\\\xc3\x04\xce\x19e\x99\xe5\xae\xf1\xf2:\x8d\x0c9\xe7\xb1t\x86\xd7\x18\xa8^u\xc8\\\xe9$\x1a\xaa}\xc6g\xf5\xa7\xf4\xca\xc1\xb9_\x1bP\x02'
        b"\xa33\xd8\xc0\xf0\x8b\xc2p\x86\xbc\x05N(\xad\xb0M\xd9\xc4\x8c'\xadD\xdd\xa4\xb3&\x93\x96\xc3\xc5\x1f\xa8\x9c\x99\xa9\xa0\x95*\xeeE\xe9/\x90\xad\xe7q;\xdbSt\x0f\xa9a\xa8\xe2v?\x95\xc0;\xd80~\xb4"
        b'@ds\x02\x107\xe7\x0b\x07R5\xc6\xc1Meh\x9fF\xc1\\\xd6f\xb2\xba\x7fk\x10\xd1\x8aCb\xdcy\x0eX\x17\xef3w\xe4^1\xee\x12\xf2\xad{\x0eb\xfe\x91\xaa\x8f\x008\x8e>{;\xeb>0\xf2\xf7'
        b'\x12\xb3\xd4\x08{\x8af\xf2\xce\x7f\nj&\x93i\xac\x03\x0fhk\x84\xdd\xa5\xc7\xe9a\xfc\xe3\xc4\xe6\x8dM\xe2\x019p\xb9\xe1h\x90]\x1f\xe4\xdb%\xd0:Dk\xc7\x0feD\xaf\x87S\xba\xab!\x8e+\x95b\x9c'
        b"\x8c\xea\xa4I\xbe3g\x02\xfc\x89\x0e\xafQ\xaf\xc9\x19\xbd\x1c-Xw\x845m8\xbd\xd0\xa6\xb4\x91i;\xb5t\xc8\xcd\xbfd7v\xcc\xd8\xc5qW'\xb4R\x02n\x81|\x125\x95m/\x80\xc6okY\x8dv"
        b'\xf9\xdf\x97\x94\x7fg\xed\x91\xe9s\xa3\xb2\x9d\x8cX\xd6l\xcdF;/p-g\xd6qZ)\x0e\xff\xa8s3}\x82\xac\xae\x02/e\xecd\x9c\xf6w\xb0I\xd8s\xca\x1aE+H\x07\x82k\x11{\x1a\xc83\x0e\x86'
        b"e\x9c\x98\xf9\x86\x96\x9b\x83\x85^\xe3\xd7'1\x8d p\xbd\xc7\xc6B\xfb<<\xefG\x17\xb4\xf5;\t_\xcf)\xf8\x04\x0e\xff7\tW3\xbb\xfek\x81\xb2\xc5\xec\x1b\xb7a\xc5&j\\\xcc\xfd\xe8\x97\xd1\x05?S"
        b'\x9f\xbc\x9a\x13\x85\x00\xdb\x9c<D,k/r\x04\xe7\xf1\xea\xbcF\x10\xdf\xae\x95\x9cP\tN\xac`\xc8\xd9\xb2\xfe\x90\x1d\xe3\xc7\xf0\xcd\xc8\xd4G\xe8\\\xd5%\x8a\x87*U\xc5:XlY\x839\x88\xd4\x06\xe7\x82\x01'
        b'\xf7\xb9]\x98-\x9e\x99\xd6,\x15\xb1\xe9t)&\xfd\x0e6\x0b7\x97\x8fp\xaa\xe7_L\xb3\x18J3V\x0e\xcb\xf5\xb2\xde\xed\xd3\x8e\x157\xd3\x83v\x08\x11p\xd3\xf6z\x1f`\xfaz\x8c\xf4\x85@\xa5\xac\xcdZ\x14'
        b'\xad\x0f<\x97\xe1K\xbe\xce\xfbC\x07{\x00\xf3;\xec3W\xbd\xcd\ni\xe9\x1d\x8e]\n\xb2rfV\xa4n)$\xa5\xd4\xabPL\x08bm\x8f\x16\xa7\xa6}\xcb\xb8\x11\x16i\x84o6\xab\xc5M~\x94P\xc4W'
        b'\xb7\xa1"\tP;\x16M\x15\xa3\xd2`\xd6\xe8s\xe2\xea\x1f,DP\xf0^\x12\x82O\xf1\x8d5\xf0k=\x03\xe1o\x89\x18l@]\xd9R/0\x8b\xa1\x83\x8e\xbd\x87z/\xb3\x13\x0b\x10\x9e\xdc\x1c+\x1b\xb6\xca\xab'
        b'Q\x13\xbf!"\x1f\xcc\xbc\xa2\x86\xa0\x9aRJ\xc92\\\xc5{2;k\x80\x94\xf9\x1d\xdf:\x99\xd2\xb5V~\x88h if\xe7N\xed\x926\xb7<\xebejfp\xc5q\xc7\xf0\xbd=\xc0\x19GR\xf7\xde\xff#'
        b'\xba\xbf=\x94\x05~4\xbf\x9d\\\xf83\x01\xdb\xc1d\xf4\xe7%\xad\xdb4\xad\x93\xaa$\xc3\xb3\xacK\xd5F\x18T\x87D\x14\x11\x10Y$a\xb5\xa9\xd8\x9f\xc9\x95\xc9rlvz\xe6\x00\xdeU\x92\xdc\x1fb\xaa\xa8\xc8'
        b'\x93\xbb\xdc\t(\xe7\xa8k3\x1e{\xaf\xf3\x80\x1d7\x18.\r\xc3\x8f\xe1.fZ\xd7%&\xdaq\x17%z\xb0\x99+\xeaL\xda|\xed \xcah\xb0\x04\xad\xfe\xe9t}\xeem=[\x0f\xc3\x8d[\xd5!\x9cw\xb3'
        b"a\xe7\xd9\tu\x96Pi\xef\xb0\x9a\xce\xa1\x02\xe4\x10X\x81\x0b\xb9~4&\xee3\x9cS%\xd2\xa9\x1e\xecX\x83<A0\x7f\x14T\xc1[Ln\xf6\xeb\\\x9c/*:\xe7\x16\xef\xfd\x0fD'\xb5\xec;@|\t"
        b'\xfb\xe8\x17j\x1d\xdb\xf4\xdc[OYU!F+\xddY#Ck\xc0\xf6B\xae\x7f\x94\x11\x84\xd5\xd6\xcf26\t3\xea\x9b7\x16\x02\xd5I\x0c\x10\x03\xf3;G\xa5(q|\xa3d\xe9=\x01Tr2!\x1c\xe3\x08'
        b'\x92`\xa2\xf8`\xff\x1b\x19\x15Qt\x00\xa2\xd4\xc6\x9e\xa8\x06\xc86\x12\x89_}=\xfd\xea\x8c\x80\x0bW#\xcb~\xd2\xb2\x01\xaa\xaa\xc1\xf1\x802\nX\x8bq>w\x863\x18\xa6\xf9\x8fP\x01\xd4\xa2\x88\xaakt\x0e'
        b'X\n-\xa7it\x01\xb4T\xa6f_^\xbc\xb09DI\t\xc3\xc7\x12\x0fL^\xbf\x01\x05\x81\x06\xd8\xc8\xc5RU\xc2=f\x1biW\x83\xa6\xee\x17\x0f<\x0cR\xaa\x1c>\x87"O,\x84\x03\x147+X\xa0c'
        b'az\x12D\xa3\xde\x05*\x17\x94:\xa2d\x80\x9cH\xd6s\xb1!\xac\x05l\x8e\x0f\x81\xc6\x9b>\xec\x0c\xbe\x80\x9b\xc7\x99\x15\xf2\x9ah\x17\x0e8\x82\x82gZ\xa3\xfaO\xb0\xf1\xa7t\x95\x8e\x9b\\\xd1kS\x01!m'
        b'\x85\x14y\xfb\xf8\xe9\x01\xd2\xbfn\x14Me\x99\xbe\x0c\xc4}7d\xa4h\x8c\xac$\n\xbd\x91\x1ft\xfa\xb3!p%\xda\xf5\xa7\xa8\x9eg\x8c}\x04@\xc1hz\x12\x82\xb7\x9b\x97\xf6\x8d\xe3C\x1b\xf5\xe1l\xec\xfd\x80'
        b'`\x0c\xe35\xb5\xd2\x87\xcfh\rw.\xce\xc8o\x0ejk\xb9\xbd+T\xddQ\x96[_\xf9\rP\x7fb@\xe0\x9c8r\xd7\xa5#\xe2x\xd9\xb8;mI\x04\xd9\xe5\xc5\x89\x88}\r\xbd9\xc4\xa5\x06\xff-\xf5\xed'
        b"\x04,\xa9?\xf5\\\x93\x0c\x82v\x10\x1e\xac\x81}=B\x9eR\xba\x1c\xc9Z\x08\xd9\x91'W\x04\xdcw\xd2x*\x81\xd2[\x9b\x90\x9f\xe1\xbe\xa1\xa6\xc9\xcc\xcfH\xc3tr\xe2F\xfb#\xf5i|n8@\xdf\x90\xfd"
        b'\xbb\xffS\xe1\x7f\xad\xeb\x94\xe6\xfe\xc9\xb8\xc6w\xdb`\xcf\x9a\xf0\x1dN]_\xc4y\x8b\xeb\x1f\x9f\xe9\x16\xb2"\xcb%_\xb1W\xe6\xd2\xe1\xb3F\xcc\x0e\xe7]\xbfk\xf0\xaf\xb6w\xab>\x84a\x8d\x13\x8c/\xfcN\x81'
        b'!\x0fP\xedp\x8fF\x189\xd6T\xe0\x9c\xee{\x9aD\xcc\xac\x1c"\nh\xees\xcdL\xdd\xf1G\xb3i\x11R\xac\xd2\xbdl\x0b\xb9#\x9c\xb0/Dg\xa9\x871ld\xa0\xbf\xd1\x0b\xcb\x11m\xf7\xda\xa3\xdc0\xf6'
        b"\xb98\x1b\x8d\xa2\x1b\xca\x8f?\x9b\x96\xe7B\xa0$\xd7)\xa2\x00+S\x01a\xd1'I}w<\xff\x0eY-\xfcS\xf4\x14\x7f\x8dbra\xc9!ZR`N\x89#\xb1\xe1\xd2\xd4W\xe4\xd0\xd0\x9f\x03\xc0\xe4\x01\xb3"
        b'\x01\x7fp\xbd\x17=\x19\x17\xb8\x01\xb6\xea\x1a\x88\xd9v\xb5\x88\xef:\xbbi8T1\x1f`\xca\x9e\xfat\x1cU,\x1fH\x9f\xf6\x1e\xbb\x11@\xc3\x8bC\xcc\x88<R\xbf\xbaX\xb8\xdf\xaaihZi\x9a\x05"\xd6P'
        b'\x8b\xd0+"v\x00\xfd\x1f\x95\xbcF\xc3\r^4\x9b\xbf\xce\xb5W\'\x90\x86p\x9cq\x91(\x89\x0fs )\xe9Z\xb5\xe9\xe2\xd7N\xf1\xab\xe5\x8a\xda\xdao]\xc8\xd7\xc9\xad\x1b.\xb5Y+)B^\xe6A\xb7w'
        b'\xc9\xe6\xfc\x11\xdb(\xaa\xb2\x99\xc5a\x01/\x06\x85p\x1a\x9c\x94=z\xe0\xc2\x1eE\xcec\xcfr\xc3S\x90\xdc\x9f\xd1\x86\xac\xe3#eO\xa2S3\xa3t$\xfc\x039\x1b\xb1\xd0\x1f\xe4\xb0\x9cv\x93\x86\x87\x82\xbf\x97'
        b'Pj\x8e\x8fB\x1d\x95\xb2\xaf\xfdV\x8b\x8d\xceY\x865\xaa\xe4\x19\x03\xc3\\j=\x8b\xaf\x17j\x82\x93\xdc\xe7T\xbe\xe8 \xddQ\x00X\xfa\x88\xee\xa1\x7f\xfb\xc5?\xb4\xfa\xaa\x00\xe8\x85$s\xf7\xb8H2\xd1\x14x'
        b'\x8d\xb0\xbal\xe7\xb2\xdd\x1c\x0c\x02\xe7.\xe4\xa6~,<\xa7\xf6\x0e\x1f\xd6\xbb\x1f+S\xd2\x92\x95\x11y\xb7]\x9a\xf9vP\xbdOO\xcd\x9e\x04\xa7\xd4\xf8\xe3v\x0c\xe4\x0b$:9\xef\x18\xa3\x83\xbe\xb6J\x86}+'
        b"\x17\x84\xe6.\xf2S\x8d\x08$\x8a^}p\xf7\x8a\xd2\\\xb6L\x80\x8e\x16\xac`\x13\x93\xcf\xf1\xa3[\xc6\xffP\xe6\xa9 \x9f\x9cgc\xa5T\xf57\x9e\x0cg{\x0eyQ\x05\xa5\x9e\rn\x08\xd7\xa1\xed\xce'x\x03"
        b'\x82GO\xd2\x81>\xd6"\xfb\xa5\xb5o\x05\xd0?\xee\x08\x0f=V[\xc8\xe0\xbcD\x03\xdb7\xc5\x02\xeevW\x16\xf6\xce\xcc\x95s_\xcc\xac!0\xd0\xa1\x14\xd4\xc1\x1b\xe5\x98\x9d\xa8\x08\xed\xa3\xcd\x89|\xae\xfe\xe1-'
        b'\x9e\xfdeG\xb0\xda\xdcb\xbd\xbe\xc9\x90\x03\xdbz\xe4pB\x8f8\x81\xac\x99\xd9s\xcc4FN)\x04\xda\x07runtimer\x03\x00\x00\x00\xda\x08__name__\xda\x08__file_'
        b'_\xa9\x00\xf3\x00\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>r\n\x00\x00\x00\x01\x00\x00\x00s\x1d\x00\x00\x00\xf0\x03\x01\x01\x01\xe5\x00 '
        b'\xd9\x00\x0b\x88H\x90h\xf0\x00\x00!db\r\xf5\x00\x00\x01eb\rr\x08\x00\x00\x00'
    ))
